"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

from collections import abc as _abc
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class PremiumMarketingComponentProperties(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    class _ButtonAction:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _ButtonActionEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PremiumMarketingComponentProperties._ButtonAction.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        BUTTON_ACTION_UNSPECIFIED: PremiumMarketingComponentProperties._ButtonAction.ValueType  # 0
        BUTTON_ACTION_OPEN_MARKETING_PAGE: PremiumMarketingComponentProperties._ButtonAction.ValueType  # 1
        BUTTON_ACTION_OPEN_TIER_2_PAYMENT_MODAL: PremiumMarketingComponentProperties._ButtonAction.ValueType  # 2
        BUTTON_ACTION_OPEN_TIER_1_PAYMENT_MODAL: PremiumMarketingComponentProperties._ButtonAction.ValueType  # 3
        BUTTON_ACTION_OPEN_TIER_2_PAYMENT_MODAL_CUSTOM_CONFIRMATION_FOOTER: PremiumMarketingComponentProperties._ButtonAction.ValueType  # 4
        BUTTON_ACTION_OPEN_PLAN_SELECTION_MODAL: PremiumMarketingComponentProperties._ButtonAction.ValueType  # 5

    class ButtonAction(_ButtonAction, metaclass=_ButtonActionEnumTypeWrapper): ...
    BUTTON_ACTION_UNSPECIFIED: PremiumMarketingComponentProperties.ButtonAction.ValueType  # 0
    BUTTON_ACTION_OPEN_MARKETING_PAGE: PremiumMarketingComponentProperties.ButtonAction.ValueType  # 1
    BUTTON_ACTION_OPEN_TIER_2_PAYMENT_MODAL: PremiumMarketingComponentProperties.ButtonAction.ValueType  # 2
    BUTTON_ACTION_OPEN_TIER_1_PAYMENT_MODAL: PremiumMarketingComponentProperties.ButtonAction.ValueType  # 3
    BUTTON_ACTION_OPEN_TIER_2_PAYMENT_MODAL_CUSTOM_CONFIRMATION_FOOTER: PremiumMarketingComponentProperties.ButtonAction.ValueType  # 4
    BUTTON_ACTION_OPEN_PLAN_SELECTION_MODAL: PremiumMarketingComponentProperties.ButtonAction.ValueType  # 5

    class _DismissibleContent:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _DismissibleContentEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PremiumMarketingComponentProperties._DismissibleContent.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        DISMISSIBLE_CONTENT_HUB_WAITLIST_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 0
        DISMISSIBLE_CONTENT_APPLICATION_COMMAND_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 1
        DISMISSIBLE_CONTENT_HUB_EVENT_HEADER_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 2
        DISMISSIBLE_CONTENT_CHANNELINFO_CHANNELBANNER_NOTICE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 3
        DISMISSIBLE_CONTENT_ACCOUNT_MULTIACCOUNT_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 4
        DISMISSIBLE_CONTENT_CHANNEL_NOTICE_INVITE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 6
        DISMISSIBLE_CONTENT_CHANNEL_NOTICE_HUBLINK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 7
        DISMISSIBLE_CONTENT_CHANNEL_NOTICE_QUICKSWITCHER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 8
        DISMISSIBLE_CONTENT_CHANNEL_NOTICE_PREMIUM_GUILD_SUBSCRIPTION: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 9
        DISMISSIBLE_CONTENT_CHANNEL_NOTICE_GUILD_BANNER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 11
        DISMISSIBLE_CONTENT_GUILD_HEADER_EVENT_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 12
        DISMISSIBLE_CONTENT_GUILD_HEADER_ANIMATED_GUILD_BANNER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 15
        DISMISSIBLE_CONTENT_NAGBAR_NOTICE_DOWNLOAD: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 16
        DISMISSIBLE_CONTENT_NAGBAR_NOTICE_CONNECT_SPOTIFY: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 17
        DISMISSIBLE_CONTENT_NAGBAR_NOTICE_CONNECT_PLAYSTATION: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 18
        DISMISSIBLE_CONTENT_ACTIVITIES_SUNSET_COACH_MARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 20
        DISMISSIBLE_CONTENT_NAGBAR_NOTICE_PREMIUM_PROMO: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 21
        DISMISSIBLE_CONTENT_NAGBAR_NOTICE_PREMIUM_TIER_TWO_TRIAL_ENDING: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 22
        DISMISSIBLE_CONTENT_NAGBAR_NOTICE_PREMIUM_REACTIVATE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 23
        DISMISSIBLE_CONTENT_PREMIUM_5TH_ANNIVERSARY_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 24
        DISMISSIBLE_CONTENT_GUILD_JOIN_FEEDBACK_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 25
        DISMISSIBLE_CONTENT_VOICE_QUALITY_BOOSTING_UPSELL_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 26
        DISMISSIBLE_CONTENT_ACTIVITIES_EARLY_USER_COACH_MARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 27
        DISMISSIBLE_CONTENT_GUILD_HEADER_SERVER_DISCOVERY_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 28
        DISMISSIBLE_CONTENT_ACTIVITIES_TUTORIAL_COACH_MARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 29
        DISMISSIBLE_CONTENT_NAGBAR_NOTICE_LOCALIZED_PRICING: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 33
        DISMISSIBLE_CONTENT_SOUNDBOARD_EDUCATION: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 35
        DISMISSIBLE_CONTENT_GUILD_HEADER_ROLE_SUBSCRIPTION_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 37
        DISMISSIBLE_CONTENT_CALL_CHAT_BUTTON_TEXT_IN_VOICE_COACH_MARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 38
        DISMISSIBLE_CONTENT_GUILD_DISCOVERY_LANDING_PAGE_SETTINGS_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 39
        DISMISSIBLE_CONTENT_GUILD_INSIGHTS_ACCESS_RATE_NEW: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 40
        DISMISSIBLE_CONTENT_NOW_PLAYING_CONSENT_CARD: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 41
        DISMISSIBLE_CONTENT_GUILD_HEADER_BOOSTING_LOW_PRICE_EXPERIMENT_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 42
        DISMISSIBLE_CONTENT_FORUM_CHANNEL_UPSELL_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 44
        DISMISSIBLE_CONTENT_POGGERMODE_BIRTHDAY_EDUCATION_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 46
        DISMISSIBLE_CONTENT_MWEB_APP_DOWNLOAD_HALFSHEET: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 47
        DISMISSIBLE_CONTENT_MWEB_APP_DOWNLOAD_NAGBAR_THEMED: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 48
        DISMISSIBLE_CONTENT_MWEB_APP_DOWNLOAD_NAGBAR_BLURPLE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 49
        DISMISSIBLE_CONTENT_GUILD_FEED_NUX_CARD: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 50
        DISMISSIBLE_CONTENT_GUILD_HEADER_FREE_STICKER_SLOTS_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 52
        DISMISSIBLE_CONTENT_ACTIVITIES_NITRO_TUTORIAL_COACH_MARK_V2: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 53
        DISMISSIBLE_CONTENT_ACTIVITIES_TEXT_INPUT_BUTTON_SPARKLES: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 55
        DISMISSIBLE_CONTENT_GUILD_DELETE_FEEDBACK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 56
        DISMISSIBLE_CONTENT_GUILD_LEAVE_FEEDBACK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 57
        DISMISSIBLE_CONTENT_AUTH_SESSIONS_NEW: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 63
        DISMISSIBLE_CONTENT_DONUT_MOBILE_NUX: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 65
        DISMISSIBLE_CONTENT_GUILD_ROLE_SUBSCRIPTION_MWEB_PURCHASE_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 66
        DISMISSIBLE_CONTENT_FORUM_CHANNEL_HELPER_CARD: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 67
        DISMISSIBLE_CONTENT_PASSPORT_USER_SETTINGS: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 70
        DISMISSIBLE_CONTENT_SUMMER_BOGO_ANNOUNCEMENT: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 71
        DISMISSIBLE_CONTENT_COMMANDS_MIGRATION_UPSELL_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 72
        DISMISSIBLE_CONTENT_FILE_LIMIT_UPLOAD_COACH_MARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 73
        DISMISSIBLE_CONTENT_DONUT_DESKTOP_NUX: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 77
        DISMISSIBLE_CONTENT_GUILD_ROLE_SUBSCRIPTION_EMOJI_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 79
        DISMISSIBLE_CONTENT_PREMIUM_SUBSCRIPTION_UPSELL_EMOJI_PICKER_TOP_OF_LIST: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 80
        DISMISSIBLE_CONTENT_STAGE_RAISED_HAND_MOVED: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 81
        DISMISSIBLE_CONTENT_XBOX_ONE_WAY_RECONNECT: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 82
        DISMISSIBLE_CONTENT_XBOX_VOICE_DESKTOP_SETTINGS_UPSELL_POPOUT: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 84
        DISMISSIBLE_CONTENT_HUB_BACK_TO_SCHOOL_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 85
        DISMISSIBLE_CONTENT_STUDENT_HUB_PRIVACY_SETTINGS_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 86
        DISMISSIBLE_CONTENT_ACTIVITIES_MOBILE_VOICE_CONTROLS_TOGGLE_NUX: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 89
        DISMISSIBLE_CONTENT_PROFILE_THEMES_SETTINGS_VIEWED_V2: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 92
        DISMISSIBLE_CONTENT_CHANNEL_LIST_OPT_IN_NUX: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 94
        DISMISSIBLE_CONTENT_ACTIVITIES_MOBILE_NUX: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 95
        DISMISSIBLE_CONTENT_PROFILE_THEMES_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 96
        DISMISSIBLE_CONTENT_GUILD_AUTOMOD_DEFAULT_ON_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 97
        DISMISSIBLE_CONTENT_CHANNEL_BROWSER_NUX: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 98
        DISMISSIBLE_CONTENT_RNA_CHANGELOG_HC_NOTICE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 99
        DISMISSIBLE_CONTENT_MESSAGE_REQUEST_SETTINGS_COACH_MARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 100
        DISMISSIBLE_CONTENT_GUILD_AUTOMOD_DEFAULT_ON_UPSELL_2: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 101
        DISMISSIBLE_CONTENT_GUILD_AUTOMOD_REGEX_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 102
        DISMISSIBLE_CONTENT_CONNECTIONS_NUX: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 108
        DISMISSIBLE_CONTENT_XBOX_VOICE_SURVEY_NAGBAR: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 110
        DISMISSIBLE_CONTENT_PS_ONE_WAY_RECONNECT: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 112
        DISMISSIBLE_CONTENT_NITRODUCTION_STEP_PROFILE_CUSTOMIZATION: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 116
        DISMISSIBLE_CONTENT_NITRODUCTION_STEP_BOOSTING: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 117
        DISMISSIBLE_CONTENT_NITRODUCTION_STEP_CUSTOM_EMOJI: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 118
        DISMISSIBLE_CONTENT_NEW_CRUNCHYROLL_CONNECTION: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 119
        DISMISSIBLE_CONTENT_APP_DIRECTORY_UPSELL_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 121
        DISMISSIBLE_CONTENT_GUILD_HEADER_COMMUNITY_ONBOARDING_ADMIN_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 124
        DISMISSIBLE_CONTENT_COMMUNITY_ONBOARDING_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 125
        DISMISSIBLE_CONTENT_VERIFIED_ROLES_COACH_MARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 127
        DISMISSIBLE_CONTENT_BLACK_FRIDAY_2022_BOGO_ANNOUNCEMENT_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 130
        DISMISSIBLE_CONTENT_GG_ANNOUNCEMENT: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 132
        DISMISSIBLE_CONTENT_CHANNEL_BROWSER_NEW_BADGE_NUX: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 133
        DISMISSIBLE_CONTENT_CREATOR_PROMO_PAGE_COACH_MARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 134
        DISMISSIBLE_CONTENT_CREATOR_MONETIZATION_ONBOARDING_V2_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 136
        DISMISSIBLE_CONTENT_GUILD_ONBOARDING_UPSELL_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 137
        DISMISSIBLE_CONTENT_NAGBAR_NOTICE_ONE_TIME_PAYMENT_PAST_DUE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 138
        DISMISSIBLE_CONTENT_DROPS_GO_LIVE_BANNER_NOTICE_HALO: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 139
        DISMISSIBLE_CONTENT_DROPS_ELIGIBILITY_ENROLLMENT_TOOLTIP_HALO: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 140
        DISMISSIBLE_CONTENT_DROPS_QUEST_COMPLETION_TOOLTIP_HALO: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 141
        DISMISSIBLE_CONTENT_NAGBAR_BOUNCED_EMAIL_NOTICE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 147
        DISMISSIBLE_CONTENT_GUILD_ONBOARDING_UPSELL_CHANNEL_NOTICE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 151
        DISMISSIBLE_CONTENT_CONSOLE_PTT_DISABLE_ALERT: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 152
        DISMISSIBLE_CONTENT_ACTIVITIES_MINI_SHELF_SPARKLES: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 153
        DISMISSIBLE_CONTENT_DROPS_ENDED_INCOMPLETE_HALO: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 154
        DISMISSIBLE_CONTENT_GDM_INVITE_REMINDER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 157
        DISMISSIBLE_CONTENT_LINKED_ROLE_ADMIN_GUILD: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 163
        DISMISSIBLE_CONTENT_NAGBAR_ACTIVATE_SERVER_SUBSCRIPTION: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 164
        DISMISSIBLE_CONTENT_BURST_REACTION_BUTTON_SPARKLE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 165
        DISMISSIBLE_CONTENT_NAGBAR_NOTICE_PREMIUM_TIER_0_TRIAL_ENDING: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 166
        DISMISSIBLE_CONTENT_VC_TILE_ACTIVITIES_ENTRY_POINT: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 167
        DISMISSIBLE_CONTENT_BURST_REACTION_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 169
        DISMISSIBLE_CONTENT_BURST_REACTIONS_REMOVE_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 170
        DISMISSIBLE_CONTENT_BURST_REACTION_NITRO_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 171
        DISMISSIBLE_CONTENT_CLIENT_THEMES_SETTINGS_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 173
        DISMISSIBLE_CONTENT_CLIENT_THEMES_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 174
        DISMISSIBLE_CONTENT_CLIENT_THEMES_SPARKLE_PREVIEW: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 175
        DISMISSIBLE_CONTENT_STAGE_V2_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 176
        DISMISSIBLE_CONTENT_QUEST_1_ENROLLMENT_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 177
        DISMISSIBLE_CONTENT_QUEST_1_COMPLETION_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 178
        DISMISSIBLE_CONTENT_QUEST_1_GO_LIVE_BANNER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 179
        DISMISSIBLE_CONTENT_QUEST_1_ENDED_INCOMPLETE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 180
        DISMISSIBLE_CONTENT_PREMIUM_TUTORIAL_EXPERIENCE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 181
        DISMISSIBLE_CONTENT_APP_DIRECTORY_SERVER_SETUP_UPSELL_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 182
        DISMISSIBLE_CONTENT_PREMIUM_TUTORIAL_FILE_UPLOAD_COMPOSER_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 183
        DISMISSIBLE_CONTENT_PREMIUM_TUTORIAL_STICKER_PICKER_COMPOSER_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 184
        DISMISSIBLE_CONTENT_PREMIUM_TUTORIAL_EMOJI_PICKER_COMPOSER_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 185
        DISMISSIBLE_CONTENT_PREMIUM_TUTORIAL_SERVER_MENU_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 186
        DISMISSIBLE_CONTENT_VOICE_MESSAGE_UPSELL_DM: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 189
        DISMISSIBLE_CONTENT_SUPER_REACTIONS_NITRO_MARKETING: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 190
        DISMISSIBLE_CONTENT_NITRO_DROP_2023_04_ANNOUNCEMENT_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 191
        DISMISSIBLE_CONTENT_CLYDE_GUILD_HEADER_NUX: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 193
        DISMISSIBLE_CONTENT_CLYDE_CHAT_BAR_NUX: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 194
        DISMISSIBLE_CONTENT_VOICE_MESSAGE_UPSELL_GUILD: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 195
        DISMISSIBLE_CONTENT_ACTIVITY_GDM_CALL_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 196
        DISMISSIBLE_CONTENT_ACTIVITY_GDM_ROCKET_SPARKLE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 197
        DISMISSIBLE_CONTENT_NITRO_DROP_2023_04_NITRO_TAB_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 205
        DISMISSIBLE_CONTENT_GUILD_ROLE_SUBSCRIPTION_IAP_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 206
        DISMISSIBLE_CONTENT_ACTIVITIES_MOBILE_PIP_FAB_NUX: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 208
        DISMISSIBLE_CONTENT_GUILD_ONBOARDING_UPSELL_HEADER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 210
        DISMISSIBLE_CONTENT_GUILD_ONBOARDING_UPSELL_NAGBAR: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 212
        DISMISSIBLE_CONTENT_GUILD_ONBOARDING_UPSELL_MODAL_V2: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 213
        DISMISSIBLE_CONTENT_SUPER_REACTIONS_FREE_USER_FIRST_SENT: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 214
        DISMISSIBLE_CONTENT_SUPER_REACTIONS_TOOLTIP_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 215
        DISMISSIBLE_CONTENT_NAGBAR_NOTICE_POMELO: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 217
        DISMISSIBLE_CONTENT_APP_DIRECTORY_GUILD_SETTINGS_NEW_INDICATOR: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 218
        DISMISSIBLE_CONTENT_APP_DIRECTORY_GUILD_SETTINGS_CONTEXT_MENU_NEW_INDICATOR: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 219
        DISMISSIBLE_CONTENT_SUPER_REACTIONS_TAB_SPARKLE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 220
        DISMISSIBLE_CONTENT_ACTIVITIES_WATCH_TOGETHER_APRIL_2023_WEEK_1_SPARKLES: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 221
        DISMISSIBLE_CONTENT_ACTIVITIES_WATCH_TOGETHER_APRIL_2023_WEEK_2_SPARKLES: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 222
        DISMISSIBLE_CONTENT_MJ_NEW_USER_CHAT_BAR: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 223
        DISMISSIBLE_CONTENT_CHANNEL_NOTICE_CLYDE_NUX: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 224
        DISMISSIBLE_CONTENT_SUPER_REACTIONS_FIRST_SENT: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 227
        DISMISSIBLE_CONTENT_COMMUNITY_GUILD_SETTINGS_SAFETY: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 228
        DISMISSIBLE_CONTENT_FRIEND_FINDER_FIRST_TIME_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 229
        DISMISSIBLE_CONTENT_SHARE_NITRO_BUTTON_SPARKLES: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 230
        DISMISSIBLE_CONTENT_PREMIUM_MOBILE_TRIAL_USER_SETTINGS_AVATAR_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 231
        DISMISSIBLE_CONTENT_SOUNDBOARD_KEYBIND_TIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 232
        DISMISSIBLE_CONTENT_QUEST_2_ENROLLMENT_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 234
        DISMISSIBLE_CONTENT_QUEST_2_COMPLETION_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 235
        DISMISSIBLE_CONTENT_QUEST_2_GO_LIVE_BANNER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 236
        DISMISSIBLE_CONTENT_QUEST_2_ENDED_INCOMPLETE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 237
        DISMISSIBLE_CONTENT_GUILD_ROLE_SUBSCRIPTION_TIER_TEMPLATES: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 238
        DISMISSIBLE_CONTENT_MEDIA_CHANNEL_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 243
        DISMISSIBLE_CONTENT_ADD_FRIENDS_WIDGET: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 244
        DISMISSIBLE_CONTENT_YOU_TAB_AVATAR_ONBOARDING: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 245
        DISMISSIBLE_CONTENT_YOU_TAB_ABOUT_ME_ONBOARDING: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 246
        DISMISSIBLE_CONTENT_GUILD_HEADER_SUMMARIES_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 247
        DISMISSIBLE_CONTENT_SUPER_REACTIONS_COACHMARK_MOBILE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 250
        DISMISSIBLE_CONTENT_SUPER_REACTIONS_SPARKLES_ACTION_SHEET_MOBILE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 251
        DISMISSIBLE_CONTENT_SERVER_SUBSCRIPTION_TIER_TEMPLATE_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 252
        DISMISSIBLE_CONTENT_EMOJI_PICKER_FAVORITE_EMOJIS_TIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 253
        DISMISSIBLE_CONTENT_SERVER_SUBSCRIPTION_SETTINGS_NEW_BADGE_TIER_TEMPLATE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 254
        DISMISSIBLE_CONTENT_SUPER_REACTIONS_MOBILE_FULLSCREEN_TAP_TO_DISMISS: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 255
        DISMISSIBLE_CONTENT_FAMILY_CENTER_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 256
        DISMISSIBLE_CONTENT_CONSOLE_LOCAL_DETECT_CTA: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 257
        DISMISSIBLE_CONTENT_REMIXING_ENTRYPOINT_EDUCATION_UPSELLS_MOBILE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 263
        DISMISSIBLE_CONTENT_GUEST_VOICE_INVITES_MENU_ITEM_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 264
        DISMISSIBLE_CONTENT_REMIXING_ENTRYPOINT_OPEN_MEDIA_KEYBOARD_UPSELL_MOBILE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 265
        DISMISSIBLE_CONTENT_GUILD_MEMBER_SAFETY_BANNER_NOTICE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 266
        DISMISSIBLE_CONTENT_INVENTORY_GUILD_SETTINGS_MODMIN_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 271
        DISMISSIBLE_CONTENT_CUSTOM_CALL_SOUNDS_PICKER_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 272
        DISMISSIBLE_CONTENT_CUSTOM_CALL_SOUNDS_SPARKLES: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 274
        DISMISSIBLE_CONTENT_SOUNDBOARD_MOBILE_FLOATING_CTA: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 275
        DISMISSIBLE_CONTENT_SOUNDBOARD_MOBILE_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 276
        DISMISSIBLE_CONTENT_PROFILE_THEMES_FEATURE_EDUCATION_TOOLTIP_TAKE_2: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 277
        DISMISSIBLE_CONTENT_VOICE_PANEL_BAD_CONNECTION_CTA: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 278
        DISMISSIBLE_CONTENT_PREMIUM_TRIAL_OFFER_MOBILE_ACTION_SHEET: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 279
        DISMISSIBLE_CONTENT_MEDIA_CHANNEL_MULTIPLE_THUMBNAIL_NOTICE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 280
        DISMISSIBLE_CONTENT_CLIPS_ONBOARDING_GO_LIVE_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 281
        DISMISSIBLE_CONTENT_CLIPS_ONBOARDING_CLIP_BUTTON_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 282
        DISMISSIBLE_CONTENT_CUSTOM_APP_ICONS_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 283
        DISMISSIBLE_CONTENT_CUSTOM_APP_ICONS_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 284
        DISMISSIBLE_CONTENT_BROADCASTING_BROADCASTER_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 285
        DISMISSIBLE_CONTENT_BROADCASTING_VIEWER_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 286
        DISMISSIBLE_CONTENT_LAUNCH_PAD_PULL_TAB_NUX: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 289
        DISMISSIBLE_CONTENT_MEMBERS_LAUNCH_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 294
        DISMISSIBLE_CONTENT_SERVER_SHOP_PHANTOM_PREVIEW: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 295
        DISMISSIBLE_CONTENT_RECURRING_CONTACT_SYNC_PROMPT: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 297
        DISMISSIBLE_CONTENT_INVENTORY_TRY_PACKS_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 302
        DISMISSIBLE_CONTENT_DEPRECATE_WIN32_MESSAGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 305
        DISMISSIBLE_CONTENT_DEKSTOP_CUSTOM_APP_ICON_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 306
        DISMISSIBLE_CONTENT_DEKSTOP_CUSTOM_APP_ICON_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 307
        DISMISSIBLE_CONTENT_CLYDE_AI_PERSONALITIES_NUX_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 312
        DISMISSIBLE_CONTENT_NUX_GUILD_CHANNEL_EXPLAINER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 313
        DISMISSIBLE_CONTENT_SUPER_REACTION_TOGGLE_EDUCATION_DESKTOP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 316
        DISMISSIBLE_CONTENT_SUPER_REACTION_TOGGLE_EDUCATION_MOBILE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 317
        DISMISSIBLE_CONTENT_SEEN_LAUNCH_WELCOME_OR_REDESIGN: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 325
        DISMISSIBLE_CONTENT_SEEN_OLD_DESIGN: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 326
        DISMISSIBLE_CONTENT_SEEN_LAUNCH_WELCOME: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 335
        DISMISSIBLE_CONTENT_FAVORITE_SERVER_ADD_TO_FAVORITES_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 336
        DISMISSIBLE_CONTENT_INVENTORY_GUILD_SETTINGS_MODMIN_COACHMARK_ROLLBACK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 337
        DISMISSIBLE_CONTENT_FRIEND_FINDER_CONTACTS_IN_NOTIFICATIONS: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 338
        DISMISSIBLE_CONTENT_OVERLAY_KEYBIND_NOTIFICATION: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 340
        DISMISSIBLE_CONTENT_CHANNEL_LIST_V2_BROWSE_CHANNELS_NUX: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 343
        DISMISSIBLE_CONTENT_HANG_STATUS_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 346
        DISMISSIBLE_CONTENT_VOICE_CALL_BG_PICKER_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 347
        DISMISSIBLE_CONTENT_VOICE_CALL_BG_PICKER_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 348
        DISMISSIBLE_CONTENT_SWIPE_TO_REPLY_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 349
        DISMISSIBLE_CONTENT_MOBILE_ACCESSIBILITY_COLOR_SETTINGS: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 350
        DISMISSIBLE_CONTENT_POLLS_CHAT_INPUT_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 354
        DISMISSIBLE_CONTENT_LOOTBOXES_ENTRYPOINT: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 358
        DISMISSIBLE_CONTENT_TENURE_REWARD_PENDING: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 360
        DISMISSIBLE_CONTENT_TENURE_REWARD_REDEEMABLE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 361
        DISMISSIBLE_CONTENT_TENURE_REWARD_REDEEMABLE_CONFETTI: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 363
        DISMISSIBLE_CONTENT_GAME_ONE_USER_SIGNUPS: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 364
        DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_SHY_COACHTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 365
        DISMISSIBLE_CONTENT_APP_LAUNCHER_ONBOARDING_BOTS_BANNER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 366
        DISMISSIBLE_CONTENT_APP_LAUNCHER_ONBOARDING_ACTIVITIES_BANNER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 367
        DISMISSIBLE_CONTENT_APP_LAUNCHER_ONBOARDING_APPS_BANNER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 368
        DISMISSIBLE_CONTENT_COLLECTIBLES_MOBILE_SHOP_MARKETING: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 369
        DISMISSIBLE_CONTENT_COLLECTIBLES_MOBILE_SHOP_HALF_SHEET: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 370
        DISMISSIBLE_CONTENT_GENSHIN_USER_SIGNUPS: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 371
        DISMISSIBLE_CONTENT_ACTIVITIES_CHAT_BUTTON_NUX_V2: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 372
        DISMISSIBLE_CONTENT_ACTIVITIES_CHAT_MENU_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 373
        DISMISSIBLE_CONTENT_PREMIUM_2024_APRIL_MARKETING_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 374
        DISMISSIBLE_CONTENT_PREMIUM_2024_APRIL_MARKETING_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 375
        DISMISSIBLE_CONTENT_REFERRAL_PROGRAM_PROGRESS_BAR_TOGGLE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 377
        DISMISSIBLE_CONTENT_REFERRAL_PROGRAM_PREMIUM_TAB_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 380
        DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_LOFI_VIBES_COACHTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 382
        DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_GALAXY_COACHTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 383
        DISMISSIBLE_CONTENT_CONTENT_INVENTORY_ONE_CLICK_REPLY_COACHTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 384
        DISMISSIBLE_CONTENT_CHANNEL_LIST_CLAN_ADMIN_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 385
        DISMISSIBLE_CONTENT_GUILD_LIST_CLAN_ADMIN_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 386
        DISMISSIBLE_CONTENT_MOBILE_NITRO_HOME_SETTINGS_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 387
        DISMISSIBLE_CONTENT_BRAND_REFRESH_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 388
        DISMISSIBLE_CONTENT_BRAND_REFRESH_BLURPLE_TWILIGHT_APP_ICON_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 389
        DISMISSIBLE_CONTENT_BRAND_REFRESH_CLIENT_THEME_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 390
        DISMISSIBLE_CONTENT_APP_LAUNCHER_USER_APP_BETA_NOTICE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 391
        DISMISSIBLE_CONTENT_COLLECTIBLES_PIRATES_MOBILE_BADGING: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 392
        DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_RETRO_AND_PIRATES_COACHTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 393
        DISMISSIBLE_CONTENT_PRIDE_ICONS: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 394
        DISMISSIBLE_CONTENT_PRIDE_ICONS_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 395
        DISMISSIBLE_CONTENT_PRIDE_ICONS_APPEARANCE_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 396
        DISMISSIBLE_CONTENT_CLAN_TAG_WAITLIST: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 397
        DISMISSIBLE_CONTENT_GUILD_LIST_CLAN_USER_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 398
        DISMISSIBLE_CONTENT_QUEST_HOME_FRIENDS_LIST_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 399
        DISMISSIBLE_CONTENT_WHATS_NEW_APP_STYLES_JUNE_2024_FLIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 400
        DISMISSIBLE_CONTENT_WHATS_NEW_CUSTOM_NOTIFICATION_SOUNDS_FLIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 401
        DISMISSIBLE_CONTENT_WHATS_NEW_REFERRAL_PROGRAM_FLIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 402
        DISMISSIBLE_CONTENT_WHATS_NEW_APP_STYLES_JUNE_2024_NITRO_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 403
        DISMISSIBLE_CONTENT_WHATS_NEW_CUSTOM_NOTIFICATION_SOUNDS_NITRO_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 404
        DISMISSIBLE_CONTENT_WHATS_NEW_REFERRAL_PROGRAM_NITRO_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 405
        DISMISSIBLE_CONTENT_WHATS_NEW_SERVER_PROFILE_FLIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 406
        DISMISSIBLE_CONTENT_WHATS_NEW_SERVER_PROFILE_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 407
        DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_ARCADE_COACHTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 408
        DISMISSIBLE_CONTENT_CHECKOUT_RECOVERY_NAGBAR: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 409
        DISMISSIBLE_CONTENT_PREMIUM_2024_JUNE_MARKETING_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 410
        DISMISSIBLE_CONTENT_APP_LAUNCHER_GLOBAL_SEARCH_ONBOARDING: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 411
        DISMISSIBLE_CONTENT_NEW_GAMING_DISCOVERY_NOTIF: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 412
        DISMISSIBLE_CONTENT_NITRO_ON_PROFILE_SIDE_PANEL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 414
        DISMISSIBLE_CONTENT_MESSAGE_FORWARDING_DESKTOP_UTILITIES_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 415
        DISMISSIBLE_CONTENT_MESSAGE_FORWARDING_MOBILE_SHEET_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 416
        DISMISSIBLE_CONTENT_SUMMER_2024_BOGO_ANNOUNCEMENT_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 417
        DISMISSIBLE_CONTENT_GIFT_INVENTORY_QUESTS_MOVED_TO_QUEST_HOME: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 421
        DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_ENTRY_MARKETING: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 422
        DISMISSIBLE_CONTENT_CASH_APP_PAY_AWARENESS_NAGBAR: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 423
        DISMISSIBLE_CONTENT_ICYMI_ALPHA_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 425
        DISMISSIBLE_CONTENT_PASSWORDLESS_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 427
        DISMISSIBLE_CONTENT_CHANNEL_LINKED_LOBBY_EDUCATION_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 429
        DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_DOJO_MARKETING: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 431
        DISMISSIBLE_CONTENT_REVERSE_TRIAL_STREAM_POPOUT: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 432
        DISMISSIBLE_CONTENT_REVERSE_TRIAL_NITRO_TAB_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 433
        DISMISSIBLE_CONTENT_REVERSE_TRIAL_EMOJI_BUTTON: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 434
        DISMISSIBLE_CONTENT_REVERSE_TRIAL_FIRST_IMPRESSION_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 435
        DISMISSIBLE_CONTENT_REVERSE_TRIAL_EMOJI_PICKER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 436
        DISMISSIBLE_CONTENT_REVERSE_TRIAL_ENDED_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 437
        DISMISSIBLE_CONTENT_VOICE_PANEL_ACTIVITIES_SHAPES_BUTTON_EDUCATION_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 439
        DISMISSIBLE_CONTENT_FOR_LATER_NOTIFICATIONS_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 440
        DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_THE_VAULT_MARKETING: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 441
        DISMISSIBLE_CONTENT_USER_DM_MUTE_FEEDBACK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 442
        DISMISSIBLE_CONTENT_RAPIDASH_M3_DISCOVERY_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 443
        DISMISSIBLE_CONTENT_WHATS_NEW_TENURE_BADGE_REWARD: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 444
        DISMISSIBLE_CONTENT_FOR_LATER_POPOUT_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 445
        DISMISSIBLE_CONTENT_GLOBAL_DISCOVERY_RAPIDASH_NOTIF: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 448
        DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_BAND_MARKETING: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 449
        DISMISSIBLE_CONTENT_RAPIDASH_MORE_GUILDS_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 452
        DISMISSIBLE_CONTENT_TRIAL_FOR_ALL_INITIAL_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 453
        DISMISSIBLE_CONTENT_TRIAL_FOR_ALL_MOBILE_SETTINGS_NOTICE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 454
        DISMISSIBLE_CONTENT_RAPIDASH_RTC_BROWSE_GUILDS: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 456
        DISMISSIBLE_CONTENT_TRIAL_FOR_ALL_MARKETING_PAGE_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 457
        DISMISSIBLE_CONTENT_USER_PROFILE_PREMIUM_AND_SHOP_ENTRY_POINTS: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 458
        DISMISSIBLE_CONTENT_TRIAL_FOR_ALL_DESKTOP_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 462
        DISMISSIBLE_CONTENT_GIFTING_PROMOTION_ICON: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 467
        DISMISSIBLE_CONTENT_GIFTING_PROMOTION_DESKTOP_FIRST_TIME_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 468
        DISMISSIBLE_CONTENT_GIFTING_PROMOTION_MOBILE_FIRST_TIME_HALFSHEET: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 469
        DISMISSIBLE_CONTENT_GIFTING_PROMOTION_REMINDER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 470
        DISMISSIBLE_CONTENT_CONSUMABLE_HD_POTION_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 471
        DISMISSIBLE_CONTENT_HD_STREAMING_POTION_MODAL_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 472
        DISMISSIBLE_CONTENT_HD_STREAMING_POTION_BANNER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 473
        DISMISSIBLE_CONTENT_GIFTING_INTENT_FRIENDS_TAB_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 474
        DISMISSIBLE_CONTENT_FRACTIONAL_NITRO_DURATION_LEFT_PILL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 476
        DISMISSIBLE_CONTENT_RESTRICTED_ACCOUNTS_SETTING_NOTICE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 479
        DISMISSIBLE_CONTENT_CONNECTIONS_XBOX_LINK_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 480
        DISMISSIBLE_CONTENT_CONNECTIONS_NEW_CONSOLE_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 481
        DISMISSIBLE_CONTENT_REFERRAL_TRIAL_MOBILE_NITRO_HOME_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 482
        DISMISSIBLE_CONTENT_SOUNDMOJI_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 483
        DISMISSIBLE_CONTENT_SOUNDMOJI_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 484
        DISMISSIBLE_CONTENT_REFERRAL_TRIAL_MOBILE_SENDER_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 485
        DISMISSIBLE_CONTENT_TRIAL_NUX_EMOJI_BUTTON: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 486
        DISMISSIBLE_CONTENT_TRIAL_NUX_EMOJI_PICKER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 487
        DISMISSIBLE_CONTENT_TRIAL_NUX_STREAM_COACH_MARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 488
        DISMISSIBLE_CONTENT_TIERED_TENURE_BADGE_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 491
        DISMISSIBLE_CONTENT_VIRTUAL_CURRENCY_ONBOARDING_ANNOUNCEMENT_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 492
        DISMISSIBLE_CONTENT_CONFETTI_POTION_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 494
        DISMISSIBLE_CONTENT_SHARE_ACTIVITY_COACHMARK_V2: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 496
        DISMISSIBLE_CONTENT_VOICE_FILTER_LOOPBACK_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 497
        DISMISSIBLE_CONTENT_VOICE_FILTER_LAUNCH_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 498
        DISMISSIBLE_CONTENT_VOICE_FILTER_IN_CALL_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 499
        DISMISSIBLE_CONTENT_REVERSE_TRIAL_NITRO_TAB_BADGE_V2: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 500
        DISMISSIBLE_CONTENT_OVERLAY_OOP_WELCOME_NUX: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 501
        DISMISSIBLE_CONTENT_OVERLAY_OOP_WELCOME_SWITCH_FROM_IP_NUX: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 502
        DISMISSIBLE_CONTENT_OVERLAY_OOP_WELCOME_BACKGROUND_NUX: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 503
        DISMISSIBLE_CONTENT_OVERLAY_OOP_WELCOME_BACKGROUND_SWITCH_FROM_IP_NUX: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 504
        DISMISSIBLE_CONTENT_OVERLAY_OOP_SETTINGS_NUX: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 505
        DISMISSIBLE_CONTENT_Q1_2025_REVERSE_TRIAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 506
        DISMISSIBLE_CONTENT_Q1_2025_FOLLOW_UP_REVERSE_TRIAL_OFFER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 507
        DISMISSIBLE_CONTENT_GUILD_POWERUPS_OVERVIEW_SIDEBAR_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 508
        DISMISSIBLE_CONTENT_SWIPE_TO_MEMBER_LIST_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 512
        DISMISSIBLE_CONTENT_VIRTUAL_CURRENCY_DISCOVERY_ONBOARDING_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 513
        DISMISSIBLE_CONTENT_VIRTUAL_CURRENCY_SHOP_ONBOARDING_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 514
        DISMISSIBLE_CONTENT_CLICKER_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 515
        DISMISSIBLE_CONTENT_RECENT_AVATARS_SETTINGS_MENU_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 516
        DISMISSIBLE_CONTENT_RECENT_AVATARS_SETTINGS_PROFILE_PAGE_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 517
        DISMISSIBLE_CONTENT_PERMADECOS_NITRO_TAB_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 518
        DISMISSIBLE_CONTENT_PERMADECOS_NITRO_HOME_CARD_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 520
        DISMISSIBLE_CONTENT_RING_USER_TO_VC_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 522
        DISMISSIBLE_CONTENT_DESKTOP_REFRESH_ONBOARDING_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 525
        DISMISSIBLE_CONTENT_GUILD_POWERUP_NOTIFICATION: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 529
        DISMISSIBLE_CONTENT_GUILD_TAG_AVAILABLE_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 530
        DISMISSIBLE_CONTENT_GUILD_POWERUP_PERKS_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 531
        DISMISSIBLE_CONTENT_THIRD_PARTY_OUTBOUND_PROMO_NAGBAR: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 532
        DISMISSIBLE_CONTENT_GUILD_TAG_USER_PROFILE_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 534
        DISMISSIBLE_CONTENT_GUILD_TAG_SERVER_SETTINGS_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 535
        DISMISSIBLE_CONTENT_GUILD_SETTINGS_ROLE_STYLES_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 536
        DISMISSIBLE_CONTENT_NAGBAR_NOTICE_IGNORE_USER_FEEDBACK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 537
        DISMISSIBLE_CONTENT_REPORT_TO_MOD_SURVEY_NOTICE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 538
        DISMISSIBLE_CONTENT_Q2_2025_MARKETING_MOMENT_NITRO_TAB_BADGE_V2: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 539
        DISMISSIBLE_CONTENT_Q2_2025_MARKETING_MOMENT_FIRST_IMPRESSION_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 540
        DISMISSIBLE_CONTENT_Q2_2025_MARKETING_MOMENT_FOLLOW_UP_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 541
        DISMISSIBLE_CONTENT_REPORT_TO_MOD_NEW_TAG: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 542
        DISMISSIBLE_CONTENT_NITRO_TENURE_BADGE_LEVEL_UP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 544
        DISMISSIBLE_CONTENT_ROBLOX_CONNECTION_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 545
        DISMISSIBLE_CONTENT_VOICE_FILTER_FIRST_USE_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 546
        DISMISSIBLE_CONTENT_CHANNEL_REORDER_MODAL_DISMISS_SETTING: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 547
        DISMISSIBLE_CONTENT_CUSTOM_THEME_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 548
        DISMISSIBLE_CONTENT_VOICE_FILTER_EARLY_ACCESS_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 549
        DISMISSIBLE_CONTENT_VOICE_FILTER_EARLY_ACCESS_PREMIUM_TAB_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 550
        DISMISSIBLE_CONTENT_CLIENT_THEMES_APPEARANCE_SETTINGS_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 551
        DISMISSIBLE_CONTENT_CUSTOM_THEME_ENTRYPOINT_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 552
        DISMISSIBLE_CONTENT_MOBILE_BOGO_PROMOTION_ACTION_SHEET: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 553
        DISMISSIBLE_CONTENT_CUSTOM_THEME_ENTRYPOINT_GRADIENT: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 554
        DISMISSIBLE_CONTENT_TIERLESS_BOOSTING_SYSTEM_MESSAGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 555
        DISMISSIBLE_CONTENT_GOOGLE_PLAY_PRICE_CHANGE_ACTION_SHEET: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 556
        DISMISSIBLE_CONTENT_REFERRAL_PROGRAM_NITRO_TAB_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 557
        DISMISSIBLE_CONTENT_ACTIVITIES_VOICE_LAUNCHER_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 558
        DISMISSIBLE_CONTENT_BOGO_2025_NITRO_TAB_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 559
        DISMISSIBLE_CONTENT_BOGO_2025_ANNOUNCEMENT_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 560
        DISMISSIBLE_CONTENT_NITRO_PRIVATE_BROWSING_SURVEY: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 563
        DISMISSIBLE_CONTENT_GUILD_POWERUP_NEW_PERK_AVAILABLE_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 564
        DISMISSIBLE_CONTENT_VANITY_URL_POWERUP_EDUCATIONAL_POPOVER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 565
        DISMISSIBLE_CONTENT_AGE_VERIFICATION_SURVEY_MODAL_CLOSE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 566
        DISMISSIBLE_CONTENT_AGE_VERIFICATION_SURVEY_MODAL_GET_STARTED: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 567
        DISMISSIBLE_CONTENT_GUILD_PIN_PERMISSION_MIGRATION_NOTIFICATION: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 568
        DISMISSIBLE_CONTENT_VANITY_URL_POWERUP_ROLLBACK_NOTIFICATION: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 569
        DISMISSIBLE_CONTENT_VANITY_URL_POWERUP_ROLLBACK_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 570
        DISMISSIBLE_CONTENT_VIRTUAL_CURRENCY_DISCOVERY_REHEAT_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 571
        DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 572
        DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 573
        DISMISSIBLE_CONTENT_NAGBAR_NOTICE_OFFER_EXPIRING: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 574
        DISMISSIBLE_CONTENT_SEARCH_AUTHOR_TYPE_FILTER_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 575
        DISMISSIBLE_CONTENT_SEARCH_AUTHOR_TYPE_SEARCH_RESULTS_HINT: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 576
        DISMISSIBLE_CONTENT_REFERRAL_PROGRAM_POPOVER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 577
        DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_NEW_BADGE_PROFILE_PAGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 579
        DISMISSIBLE_CONTENT_CLOUD_PLAY_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 580
        DISMISSIBLE_CONTENT_ACCESSIBILITY_HIGH_CONTRAST_MODE_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 583
        DISMISSIBLE_CONTENT_WIDGETS_RTC_UPSELL_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 584
        DISMISSIBLE_CONTENT_CLOUD_PLAY_POPOVER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 585
        DISMISSIBLE_CONTENT_CUSTOM_THEMES_NITRO_HOME_TILE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 586
        DISMISSIBLE_CONTENT_GUILD_HEADER_BOOST_PROGRESS_BAR_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 587
        DISMISSIBLE_CONTENT_WIDGETS_USER_SETTINGS_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 588
        DISMISSIBLE_CONTENT_WIDGETS_USER_SETTINGS_PROFILE_PAGE_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 589
        DISMISSIBLE_CONTENT_CHURN_DISCOUNT_PREMIUM_TAB_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 591
        DISMISSIBLE_CONTENT_CHURN_DISCOUNT_PREMIUM_TAB_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 592
        DISMISSIBLE_CONTENT_DOUBLE_TAP_TO_REACT_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 593
        DISMISSIBLE_CONTENT_NITRO_DROP_REWARD: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 594
        DISMISSIBLE_CONTENT_SEPTEMBER_2025_MARKETING_MOMENT_NITRO_TAB_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 595
        DISMISSIBLE_CONTENT_SEPTEMBER_2025_MARKETING_MOMENT_NITRO_TAB_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 596
        DISMISSIBLE_CONTENT_DOUBLE_TAP_TO_REACT_REMINDER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 597
        DISMISSIBLE_CONTENT_VIRTUAL_CURRENCY_MOBILE_ONBOARDING_ANNOUNCEMENT_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 598
        DISMISSIBLE_CONTENT_SEPTEMBER_MARKETING_MOMENT_ANNOUNCEMENT_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 599
        DISMISSIBLE_CONTENT_DO_NOT_DISTURB_REMINDER_POPOVER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 600
        DISMISSIBLE_CONTENT_ACCOUNT_LINK_INVITE_FRIENDS: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 601
        DISMISSIBLE_CONTENT_POST_ACCOUNT_CONNECTION_RTC_POPOVER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 602
        DISMISSIBLE_CONTENT_HALLOWEEN_APP_ICONS_APPEARANCE_SETTINGS_WEB_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 603
        DISMISSIBLE_CONTENT_HALLOWEEN_APP_ICONS_APPEARANCE_SETTINGS_MOBILE_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 604
        DISMISSIBLE_CONTENT_HALLOWEEN_APP_ICONS_TRICK_ICON_WEB_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 605
        DISMISSIBLE_CONTENT_HALLOWEEN_APP_ICONS_TREAT_ICON_WEB_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 606
        DISMISSIBLE_CONTENT_NOTIFICATION_NUDGE_DM_HOME_BANNER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 607
        DISMISSIBLE_CONTENT_NOTIFICATION_NUDGE_CHAT_BOTTOM_BANNER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 608
        DISMISSIBLE_CONTENT_NOTIFICATION_NUDGE_APP_START_BOTTOM_SHEET: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 609
        DISMISSIBLE_CONTENT_ACCOUNT_LINK_PROMPT: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 610
        DISMISSIBLE_CONTENT_WISHLIST_NUX_TOOLTIP_AND_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 611
        DISMISSIBLE_CONTENT_WIDGETS_USER_PROFILE_ACCOUNT_POPOUT_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 613
        DISMISSIBLE_CONTENT_GAME_SERVER_HOSTING_PORTKEY_TOS: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 614
        DISMISSIBLE_CONTENT_APPLICATION_WIDGET_EDIT_PROFILE_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 615
        DISMISSIBLE_CONTENT_APPLICATION_WIDGET_EDIT_PROFILE_POPOVER_LINKED: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 616
        DISMISSIBLE_CONTENT_APPLICATION_WIDGET_EDIT_PROFILE_POPOVER_UNLINKED: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 617
        DISMISSIBLE_CONTENT_APPLICATION_WIDGET_EMPTY_STATE_CARD_CONNECT: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 618
        DISMISSIBLE_CONTENT_APPLICATION_WIDGET_EMPTY_STATE_CARD_ADD_WIDGET: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 619
        DISMISSIBLE_CONTENT_GAME_SERVER_HOSTING_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 620
        DISMISSIBLE_CONTENT_WISHLIST_SHOP_BUTTON_POPOVER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 621
        DISMISSIBLE_CONTENT_HANG_STATUS_POPOVER_NUX: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 622
        DISMISSIBLE_CONTENT_REPORT_TO_MOD_EXIT_SURVEY_NOTICE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 623
        DISMISSIBLE_CONTENT_NAGBAR_NOTICE_PASSKEY_BACKUP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 624
        DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_NITRO_HOME_TILE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 625
        DISMISSIBLE_CONTENT_CROSS_DM_SEARCH_SETTING_EDUCATION_POPOVER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 627
        DISMISSIBLE_CONTENT_NITRO_TAB_BADGE_COUNTDOWN: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 630
        DISMISSIBLE_CONTENT_HOLIDAY_COACHMARK_HALLOWEEN_2025: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 631
        DISMISSIBLE_CONTENT_QUEST_HOME_ENTRYPOINT_ONBOARDING: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 632
        DISMISSIBLE_CONTENT_PREMIUM_MARKETING_MOMENT_ANNOUNCEMENT_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 633
        DISMISSIBLE_CONTENT_NITRO_TAB_BADGE_OFFER_REMINDER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 634
        DISMISSIBLE_CONTENT_VIRTUAL_CURRENCY_MOBILE_ONBOARDING_PILL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 635
        DISMISSIBLE_CONTENT_GAME_WIDGETS_USER_PROFILE_ACCOUNT_POPOUT_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 636
        DISMISSIBLE_CONTENT_RECURRING_3P_PROMOTION_POPOVER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 637
        DISMISSIBLE_CONTENT_PREMIUM_TAB_MARKETING_MOMENT_OFFER_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 638
        DISMISSIBLE_CONTENT_GAME_SERVER_HOSTING_NEW_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 639
        DISMISSIBLE_CONTENT_GAME_SHOP_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 640
        DISMISSIBLE_CONTENT_GAME_SHOP_RTC_POPOVER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 641
        DISMISSIBLE_CONTENT_GUILD_JOINT_PERMISSION_MIGRATION_NOTIFICATION: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 642
        DISMISSIBLE_CONTENT_GAME_SHOP_ANNOUNCEMENT_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 643
        DISMISSIBLE_CONTENT_CHECKPOINT_2025_BOTTOM_SHEET: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 644
        DISMISSIBLE_CONTENT_GAME_SHOP_WISHLIST_POPOVER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 645
        DISMISSIBLE_CONTENT_DISCOUNT_OFFER_ACTION_SHEET: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 646
        DISMISSIBLE_CONTENT_MOBILE_PREMIUM_TRIAL_OFFER_ACTION_SHEET: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 647
        DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_MOBILE_ANNOUNCEMENT_MODAL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 648
        DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_MOBILE_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 649
        DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_WIDE_BANNER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 650
        DISMISSIBLE_CONTENT_NITRO_PRIVACY_PERK_BETA_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 651
        DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_MOBILE_PROFILE_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 653
        DISMISSIBLE_CONTENT_CHECKPOINT_2025_DESKTOP_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 654
        DISMISSIBLE_CONTENT_APPLICATION_WIDGET_WUWA_SUGGESTED_WIDGET: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 655
        DISMISSIBLE_CONTENT_APPLICATION_WIDGET_WUWA_EDIT_PROFILE_POPOVER_LINKED: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 656
        DISMISSIBLE_CONTENT_APPLICATION_WIDGET_WUWA_EDIT_PROFILE_POPOVER_UNLINKED: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 657
        DISMISSIBLE_CONTENT_INSTALLED_GAME_COMMUNITY_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 658
        DISMISSIBLE_CONTENT_GAME_SHOP_RTC_GIFTING_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 659
        DISMISSIBLE_CONTENT_GAME_INVITE_ACCOUNT_LINK_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 660
        DISMISSIBLE_CONTENT_NITRO_PRIVACY_PERK_NEW_BADGE_V2: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 661
        DISMISSIBLE_CONTENT_GUILD_TAG_AVAILABLE_COACHMARK_V2: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 662
        DISMISSIBLE_CONTENT_GUILD_TAG_UPDATED_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 663
        DISMISSIBLE_CONTENT_ORB_RENTAL_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 664
        DISMISSIBLE_CONTENT_HOLIDAY_COACHMARK_WINTER_2025: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 665
        DISMISSIBLE_CONTENT_WISHLIST_USER_PROFILE_ACCOUNT_POPOUT_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 666
        DISMISSIBLE_CONTENT_TRIAL_FOR_ALL_2026_SETTINGS_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 667
        DISMISSIBLE_CONTENT_PREMIUM_GROUP_POPOVER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 668
        DISMISSIBLE_CONTENT_PREMIUM_ORBS_UPSELL_POPOVER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 669
        DISMISSIBLE_CONTENT_PREMIUM_ORBS_REWARDS_DROP_POPOVER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 670
        DISMISSIBLE_CONTENT_GAME_SERVER_HOSTING_NEW_PERK_AVAILABLE_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 672
        DISMISSIBLE_CONTENT_PREMIUM_ORBS_REWARDS_INTRO_POPOVER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 673
        DISMISSIBLE_CONTENT_BOOST_PROGRESS_BAR_ADMIN_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 674
        DISMISSIBLE_CONTENT_BOOST_PROGRESS_BAR_MEMBER_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 675
        DISMISSIBLE_CONTENT_QUEST_HOME_ENTRYPOINT_TAKEOVER_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 676
        DISMISSIBLE_CONTENT_SLAYER_STOREFRONT_XBOX_ANNOUNCEMENT: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 677
        DISMISSIBLE_CONTENT_BOOST_TO_UNLOCK_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 678
        DISMISSIBLE_CONTENT_WISHLIST_MOBILE_NUX_PRODUCT_CARD_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 679
        DISMISSIBLE_CONTENT_WISHLIST_MOBILE_NUX_ACTION_SHEET: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 680
        DISMISSIBLE_CONTENT_WISHLIST_MOBILE_YOU_SCREEN_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 681
        DISMISSIBLE_CONTENT_GAME_CLAIM_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 682
        DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_MARVEL_RIVALS_ORBS_REWARD: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 683
        DISMISSIBLE_CONTENT_EXPIRING_POWERUP_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 684
        DISMISSIBLE_CONTENT_FIRST_BOOSTER_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 685
        DISMISSIBLE_CONTENT_REFERRAL_PROGRAM_POPOVER_V2: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 686
        DISMISSIBLE_CONTENT_QUEST_HOME_ENTRYPOINT_HERO_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 687
        DISMISSIBLE_CONTENT_GAME_DETECTION_CREATE_GAME_SERVER_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 688
        DISMISSIBLE_CONTENT_GAME_DETECTION_CREATE_GAME_SERVER_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 689
        DISMISSIBLE_CONTENT_JOIN_GAME_COMMUNITY_RTC_CTA: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 690
        DISMISSIBLE_CONTENT_NAGBAR_QUEST_APP_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 691
        DISMISSIBLE_CONTENT_GAME_SHOP_ORBS_REWARD_BANNER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 692
        DISMISSIBLE_CONTENT_SLAYER_STOREFRONT_ORBS_REWARDS_ANNOUNCEMENT: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 693
        DISMISSIBLE_CONTENT_FAVORITES_SERVER_ONBOARDING_INTRO: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 694
        DISMISSIBLE_CONTENT_FAVORITES_SERVER_ONBOARDING_MENU_ITEM: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 695
        DISMISSIBLE_CONTENT_GIFT_INTENT_MESSAGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 696
        DISMISSIBLE_CONTENT_MOBILE_REFERRAL_PROGRAM_BOTTOM_SHEET_ENTRYPOINT: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 697
        DISMISSIBLE_CONTENT_GAME_ACCOUNT_LINK_RECURRING_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 698
        DISMISSIBLE_CONTENT_WISHLIST_MOBILE_VIEWER_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 699
        DISMISSIBLE_CONTENT_EMPTY_GAME_SERVER_TAB: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 700
        DISMISSIBLE_CONTENT_GUILD_POWERUPS_OVERVIEW_SIDEBAR_VIDEO_CARD: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 701
        DISMISSIBLE_CONTENT_SLAYER_STOREFRONT_ORBS_REWARD_WISHLIST_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 702
        DISMISSIBLE_CONTENT_USER_PROFILE_WISHLIST_RECOMMENDATIONS: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 703
        DISMISSIBLE_CONTENT_GAME_SERVER_HOSTING_BATCH_RELEASE_V2_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 704
        DISMISSIBLE_CONTENT_QUEST_ACTIVITY_HEADER_INTRO: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 705
        DISMISSIBLE_CONTENT_GAME_SERVER_GAME_DETECTION_UPSELL_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 706
        DISMISSIBLE_CONTENT_REFERRAL_PROGRAM_ENTRYPOINT_NITRO_TAB_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 707
        DISMISSIBLE_CONTENT_DOUBLE_TAP_TO_REACT_EXPANDED_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 708
        DISMISSIBLE_CONTENT_FAVORITES_GUILD_NEW_BADGE: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 709
        DISMISSIBLE_CONTENT_FIRST_BOOSTER_UPSELL_OVERSEER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 710
        DISMISSIBLE_CONTENT_MOBILE_MULTI_GUILD_CREATE_UPSELL_ANIMATION: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 711
        DISMISSIBLE_CONTENT_PREMIUM_MARKETING_MOMENT_REMINDER_UPSELL: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 712
        DISMISSIBLE_CONTENT_GAME_SERVER_PRICING_CHANGE_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 713
        DISMISSIBLE_CONTENT_PREMIUM_WISHLIST_COACHMARK: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 714
        DISMISSIBLE_CONTENT_PREMIUM_GROUP_POPOVER_UPSELL_V2: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 715
        DISMISSIBLE_CONTENT_L_3PP_NON_NITRO_POPOVER: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 716
        DISMISSIBLE_CONTENT_L_3PP_NITRO_TOOLTIP: PremiumMarketingComponentProperties._DismissibleContent.ValueType  # 717

    class DismissibleContent(_DismissibleContent, metaclass=_DismissibleContentEnumTypeWrapper): ...
    DISMISSIBLE_CONTENT_HUB_WAITLIST_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 0
    DISMISSIBLE_CONTENT_APPLICATION_COMMAND_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 1
    DISMISSIBLE_CONTENT_HUB_EVENT_HEADER_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 2
    DISMISSIBLE_CONTENT_CHANNELINFO_CHANNELBANNER_NOTICE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 3
    DISMISSIBLE_CONTENT_ACCOUNT_MULTIACCOUNT_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 4
    DISMISSIBLE_CONTENT_CHANNEL_NOTICE_INVITE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 6
    DISMISSIBLE_CONTENT_CHANNEL_NOTICE_HUBLINK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 7
    DISMISSIBLE_CONTENT_CHANNEL_NOTICE_QUICKSWITCHER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 8
    DISMISSIBLE_CONTENT_CHANNEL_NOTICE_PREMIUM_GUILD_SUBSCRIPTION: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 9
    DISMISSIBLE_CONTENT_CHANNEL_NOTICE_GUILD_BANNER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 11
    DISMISSIBLE_CONTENT_GUILD_HEADER_EVENT_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 12
    DISMISSIBLE_CONTENT_GUILD_HEADER_ANIMATED_GUILD_BANNER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 15
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_DOWNLOAD: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 16
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_CONNECT_SPOTIFY: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 17
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_CONNECT_PLAYSTATION: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 18
    DISMISSIBLE_CONTENT_ACTIVITIES_SUNSET_COACH_MARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 20
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_PREMIUM_PROMO: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 21
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_PREMIUM_TIER_TWO_TRIAL_ENDING: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 22
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_PREMIUM_REACTIVATE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 23
    DISMISSIBLE_CONTENT_PREMIUM_5TH_ANNIVERSARY_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 24
    DISMISSIBLE_CONTENT_GUILD_JOIN_FEEDBACK_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 25
    DISMISSIBLE_CONTENT_VOICE_QUALITY_BOOSTING_UPSELL_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 26
    DISMISSIBLE_CONTENT_ACTIVITIES_EARLY_USER_COACH_MARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 27
    DISMISSIBLE_CONTENT_GUILD_HEADER_SERVER_DISCOVERY_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 28
    DISMISSIBLE_CONTENT_ACTIVITIES_TUTORIAL_COACH_MARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 29
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_LOCALIZED_PRICING: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 33
    DISMISSIBLE_CONTENT_SOUNDBOARD_EDUCATION: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 35
    DISMISSIBLE_CONTENT_GUILD_HEADER_ROLE_SUBSCRIPTION_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 37
    DISMISSIBLE_CONTENT_CALL_CHAT_BUTTON_TEXT_IN_VOICE_COACH_MARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 38
    DISMISSIBLE_CONTENT_GUILD_DISCOVERY_LANDING_PAGE_SETTINGS_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 39
    DISMISSIBLE_CONTENT_GUILD_INSIGHTS_ACCESS_RATE_NEW: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 40
    DISMISSIBLE_CONTENT_NOW_PLAYING_CONSENT_CARD: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 41
    DISMISSIBLE_CONTENT_GUILD_HEADER_BOOSTING_LOW_PRICE_EXPERIMENT_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 42
    DISMISSIBLE_CONTENT_FORUM_CHANNEL_UPSELL_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 44
    DISMISSIBLE_CONTENT_POGGERMODE_BIRTHDAY_EDUCATION_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 46
    DISMISSIBLE_CONTENT_MWEB_APP_DOWNLOAD_HALFSHEET: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 47
    DISMISSIBLE_CONTENT_MWEB_APP_DOWNLOAD_NAGBAR_THEMED: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 48
    DISMISSIBLE_CONTENT_MWEB_APP_DOWNLOAD_NAGBAR_BLURPLE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 49
    DISMISSIBLE_CONTENT_GUILD_FEED_NUX_CARD: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 50
    DISMISSIBLE_CONTENT_GUILD_HEADER_FREE_STICKER_SLOTS_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 52
    DISMISSIBLE_CONTENT_ACTIVITIES_NITRO_TUTORIAL_COACH_MARK_V2: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 53
    DISMISSIBLE_CONTENT_ACTIVITIES_TEXT_INPUT_BUTTON_SPARKLES: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 55
    DISMISSIBLE_CONTENT_GUILD_DELETE_FEEDBACK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 56
    DISMISSIBLE_CONTENT_GUILD_LEAVE_FEEDBACK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 57
    DISMISSIBLE_CONTENT_AUTH_SESSIONS_NEW: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 63
    DISMISSIBLE_CONTENT_DONUT_MOBILE_NUX: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 65
    DISMISSIBLE_CONTENT_GUILD_ROLE_SUBSCRIPTION_MWEB_PURCHASE_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 66
    DISMISSIBLE_CONTENT_FORUM_CHANNEL_HELPER_CARD: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 67
    DISMISSIBLE_CONTENT_PASSPORT_USER_SETTINGS: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 70
    DISMISSIBLE_CONTENT_SUMMER_BOGO_ANNOUNCEMENT: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 71
    DISMISSIBLE_CONTENT_COMMANDS_MIGRATION_UPSELL_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 72
    DISMISSIBLE_CONTENT_FILE_LIMIT_UPLOAD_COACH_MARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 73
    DISMISSIBLE_CONTENT_DONUT_DESKTOP_NUX: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 77
    DISMISSIBLE_CONTENT_GUILD_ROLE_SUBSCRIPTION_EMOJI_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 79
    DISMISSIBLE_CONTENT_PREMIUM_SUBSCRIPTION_UPSELL_EMOJI_PICKER_TOP_OF_LIST: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 80
    DISMISSIBLE_CONTENT_STAGE_RAISED_HAND_MOVED: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 81
    DISMISSIBLE_CONTENT_XBOX_ONE_WAY_RECONNECT: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 82
    DISMISSIBLE_CONTENT_XBOX_VOICE_DESKTOP_SETTINGS_UPSELL_POPOUT: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 84
    DISMISSIBLE_CONTENT_HUB_BACK_TO_SCHOOL_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 85
    DISMISSIBLE_CONTENT_STUDENT_HUB_PRIVACY_SETTINGS_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 86
    DISMISSIBLE_CONTENT_ACTIVITIES_MOBILE_VOICE_CONTROLS_TOGGLE_NUX: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 89
    DISMISSIBLE_CONTENT_PROFILE_THEMES_SETTINGS_VIEWED_V2: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 92
    DISMISSIBLE_CONTENT_CHANNEL_LIST_OPT_IN_NUX: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 94
    DISMISSIBLE_CONTENT_ACTIVITIES_MOBILE_NUX: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 95
    DISMISSIBLE_CONTENT_PROFILE_THEMES_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 96
    DISMISSIBLE_CONTENT_GUILD_AUTOMOD_DEFAULT_ON_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 97
    DISMISSIBLE_CONTENT_CHANNEL_BROWSER_NUX: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 98
    DISMISSIBLE_CONTENT_RNA_CHANGELOG_HC_NOTICE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 99
    DISMISSIBLE_CONTENT_MESSAGE_REQUEST_SETTINGS_COACH_MARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 100
    DISMISSIBLE_CONTENT_GUILD_AUTOMOD_DEFAULT_ON_UPSELL_2: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 101
    DISMISSIBLE_CONTENT_GUILD_AUTOMOD_REGEX_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 102
    DISMISSIBLE_CONTENT_CONNECTIONS_NUX: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 108
    DISMISSIBLE_CONTENT_XBOX_VOICE_SURVEY_NAGBAR: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 110
    DISMISSIBLE_CONTENT_PS_ONE_WAY_RECONNECT: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 112
    DISMISSIBLE_CONTENT_NITRODUCTION_STEP_PROFILE_CUSTOMIZATION: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 116
    DISMISSIBLE_CONTENT_NITRODUCTION_STEP_BOOSTING: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 117
    DISMISSIBLE_CONTENT_NITRODUCTION_STEP_CUSTOM_EMOJI: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 118
    DISMISSIBLE_CONTENT_NEW_CRUNCHYROLL_CONNECTION: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 119
    DISMISSIBLE_CONTENT_APP_DIRECTORY_UPSELL_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 121
    DISMISSIBLE_CONTENT_GUILD_HEADER_COMMUNITY_ONBOARDING_ADMIN_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 124
    DISMISSIBLE_CONTENT_COMMUNITY_ONBOARDING_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 125
    DISMISSIBLE_CONTENT_VERIFIED_ROLES_COACH_MARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 127
    DISMISSIBLE_CONTENT_BLACK_FRIDAY_2022_BOGO_ANNOUNCEMENT_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 130
    DISMISSIBLE_CONTENT_GG_ANNOUNCEMENT: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 132
    DISMISSIBLE_CONTENT_CHANNEL_BROWSER_NEW_BADGE_NUX: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 133
    DISMISSIBLE_CONTENT_CREATOR_PROMO_PAGE_COACH_MARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 134
    DISMISSIBLE_CONTENT_CREATOR_MONETIZATION_ONBOARDING_V2_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 136
    DISMISSIBLE_CONTENT_GUILD_ONBOARDING_UPSELL_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 137
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_ONE_TIME_PAYMENT_PAST_DUE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 138
    DISMISSIBLE_CONTENT_DROPS_GO_LIVE_BANNER_NOTICE_HALO: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 139
    DISMISSIBLE_CONTENT_DROPS_ELIGIBILITY_ENROLLMENT_TOOLTIP_HALO: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 140
    DISMISSIBLE_CONTENT_DROPS_QUEST_COMPLETION_TOOLTIP_HALO: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 141
    DISMISSIBLE_CONTENT_NAGBAR_BOUNCED_EMAIL_NOTICE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 147
    DISMISSIBLE_CONTENT_GUILD_ONBOARDING_UPSELL_CHANNEL_NOTICE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 151
    DISMISSIBLE_CONTENT_CONSOLE_PTT_DISABLE_ALERT: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 152
    DISMISSIBLE_CONTENT_ACTIVITIES_MINI_SHELF_SPARKLES: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 153
    DISMISSIBLE_CONTENT_DROPS_ENDED_INCOMPLETE_HALO: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 154
    DISMISSIBLE_CONTENT_GDM_INVITE_REMINDER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 157
    DISMISSIBLE_CONTENT_LINKED_ROLE_ADMIN_GUILD: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 163
    DISMISSIBLE_CONTENT_NAGBAR_ACTIVATE_SERVER_SUBSCRIPTION: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 164
    DISMISSIBLE_CONTENT_BURST_REACTION_BUTTON_SPARKLE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 165
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_PREMIUM_TIER_0_TRIAL_ENDING: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 166
    DISMISSIBLE_CONTENT_VC_TILE_ACTIVITIES_ENTRY_POINT: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 167
    DISMISSIBLE_CONTENT_BURST_REACTION_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 169
    DISMISSIBLE_CONTENT_BURST_REACTIONS_REMOVE_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 170
    DISMISSIBLE_CONTENT_BURST_REACTION_NITRO_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 171
    DISMISSIBLE_CONTENT_CLIENT_THEMES_SETTINGS_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 173
    DISMISSIBLE_CONTENT_CLIENT_THEMES_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 174
    DISMISSIBLE_CONTENT_CLIENT_THEMES_SPARKLE_PREVIEW: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 175
    DISMISSIBLE_CONTENT_STAGE_V2_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 176
    DISMISSIBLE_CONTENT_QUEST_1_ENROLLMENT_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 177
    DISMISSIBLE_CONTENT_QUEST_1_COMPLETION_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 178
    DISMISSIBLE_CONTENT_QUEST_1_GO_LIVE_BANNER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 179
    DISMISSIBLE_CONTENT_QUEST_1_ENDED_INCOMPLETE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 180
    DISMISSIBLE_CONTENT_PREMIUM_TUTORIAL_EXPERIENCE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 181
    DISMISSIBLE_CONTENT_APP_DIRECTORY_SERVER_SETUP_UPSELL_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 182
    DISMISSIBLE_CONTENT_PREMIUM_TUTORIAL_FILE_UPLOAD_COMPOSER_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 183
    DISMISSIBLE_CONTENT_PREMIUM_TUTORIAL_STICKER_PICKER_COMPOSER_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 184
    DISMISSIBLE_CONTENT_PREMIUM_TUTORIAL_EMOJI_PICKER_COMPOSER_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 185
    DISMISSIBLE_CONTENT_PREMIUM_TUTORIAL_SERVER_MENU_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 186
    DISMISSIBLE_CONTENT_VOICE_MESSAGE_UPSELL_DM: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 189
    DISMISSIBLE_CONTENT_SUPER_REACTIONS_NITRO_MARKETING: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 190
    DISMISSIBLE_CONTENT_NITRO_DROP_2023_04_ANNOUNCEMENT_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 191
    DISMISSIBLE_CONTENT_CLYDE_GUILD_HEADER_NUX: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 193
    DISMISSIBLE_CONTENT_CLYDE_CHAT_BAR_NUX: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 194
    DISMISSIBLE_CONTENT_VOICE_MESSAGE_UPSELL_GUILD: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 195
    DISMISSIBLE_CONTENT_ACTIVITY_GDM_CALL_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 196
    DISMISSIBLE_CONTENT_ACTIVITY_GDM_ROCKET_SPARKLE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 197
    DISMISSIBLE_CONTENT_NITRO_DROP_2023_04_NITRO_TAB_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 205
    DISMISSIBLE_CONTENT_GUILD_ROLE_SUBSCRIPTION_IAP_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 206
    DISMISSIBLE_CONTENT_ACTIVITIES_MOBILE_PIP_FAB_NUX: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 208
    DISMISSIBLE_CONTENT_GUILD_ONBOARDING_UPSELL_HEADER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 210
    DISMISSIBLE_CONTENT_GUILD_ONBOARDING_UPSELL_NAGBAR: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 212
    DISMISSIBLE_CONTENT_GUILD_ONBOARDING_UPSELL_MODAL_V2: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 213
    DISMISSIBLE_CONTENT_SUPER_REACTIONS_FREE_USER_FIRST_SENT: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 214
    DISMISSIBLE_CONTENT_SUPER_REACTIONS_TOOLTIP_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 215
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_POMELO: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 217
    DISMISSIBLE_CONTENT_APP_DIRECTORY_GUILD_SETTINGS_NEW_INDICATOR: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 218
    DISMISSIBLE_CONTENT_APP_DIRECTORY_GUILD_SETTINGS_CONTEXT_MENU_NEW_INDICATOR: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 219
    DISMISSIBLE_CONTENT_SUPER_REACTIONS_TAB_SPARKLE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 220
    DISMISSIBLE_CONTENT_ACTIVITIES_WATCH_TOGETHER_APRIL_2023_WEEK_1_SPARKLES: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 221
    DISMISSIBLE_CONTENT_ACTIVITIES_WATCH_TOGETHER_APRIL_2023_WEEK_2_SPARKLES: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 222
    DISMISSIBLE_CONTENT_MJ_NEW_USER_CHAT_BAR: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 223
    DISMISSIBLE_CONTENT_CHANNEL_NOTICE_CLYDE_NUX: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 224
    DISMISSIBLE_CONTENT_SUPER_REACTIONS_FIRST_SENT: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 227
    DISMISSIBLE_CONTENT_COMMUNITY_GUILD_SETTINGS_SAFETY: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 228
    DISMISSIBLE_CONTENT_FRIEND_FINDER_FIRST_TIME_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 229
    DISMISSIBLE_CONTENT_SHARE_NITRO_BUTTON_SPARKLES: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 230
    DISMISSIBLE_CONTENT_PREMIUM_MOBILE_TRIAL_USER_SETTINGS_AVATAR_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 231
    DISMISSIBLE_CONTENT_SOUNDBOARD_KEYBIND_TIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 232
    DISMISSIBLE_CONTENT_QUEST_2_ENROLLMENT_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 234
    DISMISSIBLE_CONTENT_QUEST_2_COMPLETION_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 235
    DISMISSIBLE_CONTENT_QUEST_2_GO_LIVE_BANNER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 236
    DISMISSIBLE_CONTENT_QUEST_2_ENDED_INCOMPLETE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 237
    DISMISSIBLE_CONTENT_GUILD_ROLE_SUBSCRIPTION_TIER_TEMPLATES: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 238
    DISMISSIBLE_CONTENT_MEDIA_CHANNEL_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 243
    DISMISSIBLE_CONTENT_ADD_FRIENDS_WIDGET: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 244
    DISMISSIBLE_CONTENT_YOU_TAB_AVATAR_ONBOARDING: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 245
    DISMISSIBLE_CONTENT_YOU_TAB_ABOUT_ME_ONBOARDING: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 246
    DISMISSIBLE_CONTENT_GUILD_HEADER_SUMMARIES_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 247
    DISMISSIBLE_CONTENT_SUPER_REACTIONS_COACHMARK_MOBILE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 250
    DISMISSIBLE_CONTENT_SUPER_REACTIONS_SPARKLES_ACTION_SHEET_MOBILE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 251
    DISMISSIBLE_CONTENT_SERVER_SUBSCRIPTION_TIER_TEMPLATE_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 252
    DISMISSIBLE_CONTENT_EMOJI_PICKER_FAVORITE_EMOJIS_TIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 253
    DISMISSIBLE_CONTENT_SERVER_SUBSCRIPTION_SETTINGS_NEW_BADGE_TIER_TEMPLATE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 254
    DISMISSIBLE_CONTENT_SUPER_REACTIONS_MOBILE_FULLSCREEN_TAP_TO_DISMISS: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 255
    DISMISSIBLE_CONTENT_FAMILY_CENTER_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 256
    DISMISSIBLE_CONTENT_CONSOLE_LOCAL_DETECT_CTA: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 257
    DISMISSIBLE_CONTENT_REMIXING_ENTRYPOINT_EDUCATION_UPSELLS_MOBILE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 263
    DISMISSIBLE_CONTENT_GUEST_VOICE_INVITES_MENU_ITEM_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 264
    DISMISSIBLE_CONTENT_REMIXING_ENTRYPOINT_OPEN_MEDIA_KEYBOARD_UPSELL_MOBILE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 265
    DISMISSIBLE_CONTENT_GUILD_MEMBER_SAFETY_BANNER_NOTICE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 266
    DISMISSIBLE_CONTENT_INVENTORY_GUILD_SETTINGS_MODMIN_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 271
    DISMISSIBLE_CONTENT_CUSTOM_CALL_SOUNDS_PICKER_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 272
    DISMISSIBLE_CONTENT_CUSTOM_CALL_SOUNDS_SPARKLES: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 274
    DISMISSIBLE_CONTENT_SOUNDBOARD_MOBILE_FLOATING_CTA: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 275
    DISMISSIBLE_CONTENT_SOUNDBOARD_MOBILE_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 276
    DISMISSIBLE_CONTENT_PROFILE_THEMES_FEATURE_EDUCATION_TOOLTIP_TAKE_2: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 277
    DISMISSIBLE_CONTENT_VOICE_PANEL_BAD_CONNECTION_CTA: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 278
    DISMISSIBLE_CONTENT_PREMIUM_TRIAL_OFFER_MOBILE_ACTION_SHEET: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 279
    DISMISSIBLE_CONTENT_MEDIA_CHANNEL_MULTIPLE_THUMBNAIL_NOTICE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 280
    DISMISSIBLE_CONTENT_CLIPS_ONBOARDING_GO_LIVE_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 281
    DISMISSIBLE_CONTENT_CLIPS_ONBOARDING_CLIP_BUTTON_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 282
    DISMISSIBLE_CONTENT_CUSTOM_APP_ICONS_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 283
    DISMISSIBLE_CONTENT_CUSTOM_APP_ICONS_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 284
    DISMISSIBLE_CONTENT_BROADCASTING_BROADCASTER_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 285
    DISMISSIBLE_CONTENT_BROADCASTING_VIEWER_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 286
    DISMISSIBLE_CONTENT_LAUNCH_PAD_PULL_TAB_NUX: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 289
    DISMISSIBLE_CONTENT_MEMBERS_LAUNCH_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 294
    DISMISSIBLE_CONTENT_SERVER_SHOP_PHANTOM_PREVIEW: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 295
    DISMISSIBLE_CONTENT_RECURRING_CONTACT_SYNC_PROMPT: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 297
    DISMISSIBLE_CONTENT_INVENTORY_TRY_PACKS_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 302
    DISMISSIBLE_CONTENT_DEPRECATE_WIN32_MESSAGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 305
    DISMISSIBLE_CONTENT_DEKSTOP_CUSTOM_APP_ICON_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 306
    DISMISSIBLE_CONTENT_DEKSTOP_CUSTOM_APP_ICON_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 307
    DISMISSIBLE_CONTENT_CLYDE_AI_PERSONALITIES_NUX_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 312
    DISMISSIBLE_CONTENT_NUX_GUILD_CHANNEL_EXPLAINER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 313
    DISMISSIBLE_CONTENT_SUPER_REACTION_TOGGLE_EDUCATION_DESKTOP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 316
    DISMISSIBLE_CONTENT_SUPER_REACTION_TOGGLE_EDUCATION_MOBILE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 317
    DISMISSIBLE_CONTENT_SEEN_LAUNCH_WELCOME_OR_REDESIGN: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 325
    DISMISSIBLE_CONTENT_SEEN_OLD_DESIGN: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 326
    DISMISSIBLE_CONTENT_SEEN_LAUNCH_WELCOME: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 335
    DISMISSIBLE_CONTENT_FAVORITE_SERVER_ADD_TO_FAVORITES_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 336
    DISMISSIBLE_CONTENT_INVENTORY_GUILD_SETTINGS_MODMIN_COACHMARK_ROLLBACK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 337
    DISMISSIBLE_CONTENT_FRIEND_FINDER_CONTACTS_IN_NOTIFICATIONS: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 338
    DISMISSIBLE_CONTENT_OVERLAY_KEYBIND_NOTIFICATION: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 340
    DISMISSIBLE_CONTENT_CHANNEL_LIST_V2_BROWSE_CHANNELS_NUX: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 343
    DISMISSIBLE_CONTENT_HANG_STATUS_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 346
    DISMISSIBLE_CONTENT_VOICE_CALL_BG_PICKER_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 347
    DISMISSIBLE_CONTENT_VOICE_CALL_BG_PICKER_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 348
    DISMISSIBLE_CONTENT_SWIPE_TO_REPLY_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 349
    DISMISSIBLE_CONTENT_MOBILE_ACCESSIBILITY_COLOR_SETTINGS: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 350
    DISMISSIBLE_CONTENT_POLLS_CHAT_INPUT_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 354
    DISMISSIBLE_CONTENT_LOOTBOXES_ENTRYPOINT: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 358
    DISMISSIBLE_CONTENT_TENURE_REWARD_PENDING: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 360
    DISMISSIBLE_CONTENT_TENURE_REWARD_REDEEMABLE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 361
    DISMISSIBLE_CONTENT_TENURE_REWARD_REDEEMABLE_CONFETTI: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 363
    DISMISSIBLE_CONTENT_GAME_ONE_USER_SIGNUPS: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 364
    DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_SHY_COACHTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 365
    DISMISSIBLE_CONTENT_APP_LAUNCHER_ONBOARDING_BOTS_BANNER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 366
    DISMISSIBLE_CONTENT_APP_LAUNCHER_ONBOARDING_ACTIVITIES_BANNER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 367
    DISMISSIBLE_CONTENT_APP_LAUNCHER_ONBOARDING_APPS_BANNER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 368
    DISMISSIBLE_CONTENT_COLLECTIBLES_MOBILE_SHOP_MARKETING: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 369
    DISMISSIBLE_CONTENT_COLLECTIBLES_MOBILE_SHOP_HALF_SHEET: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 370
    DISMISSIBLE_CONTENT_GENSHIN_USER_SIGNUPS: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 371
    DISMISSIBLE_CONTENT_ACTIVITIES_CHAT_BUTTON_NUX_V2: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 372
    DISMISSIBLE_CONTENT_ACTIVITIES_CHAT_MENU_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 373
    DISMISSIBLE_CONTENT_PREMIUM_2024_APRIL_MARKETING_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 374
    DISMISSIBLE_CONTENT_PREMIUM_2024_APRIL_MARKETING_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 375
    DISMISSIBLE_CONTENT_REFERRAL_PROGRAM_PROGRESS_BAR_TOGGLE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 377
    DISMISSIBLE_CONTENT_REFERRAL_PROGRAM_PREMIUM_TAB_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 380
    DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_LOFI_VIBES_COACHTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 382
    DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_GALAXY_COACHTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 383
    DISMISSIBLE_CONTENT_CONTENT_INVENTORY_ONE_CLICK_REPLY_COACHTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 384
    DISMISSIBLE_CONTENT_CHANNEL_LIST_CLAN_ADMIN_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 385
    DISMISSIBLE_CONTENT_GUILD_LIST_CLAN_ADMIN_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 386
    DISMISSIBLE_CONTENT_MOBILE_NITRO_HOME_SETTINGS_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 387
    DISMISSIBLE_CONTENT_BRAND_REFRESH_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 388
    DISMISSIBLE_CONTENT_BRAND_REFRESH_BLURPLE_TWILIGHT_APP_ICON_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 389
    DISMISSIBLE_CONTENT_BRAND_REFRESH_CLIENT_THEME_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 390
    DISMISSIBLE_CONTENT_APP_LAUNCHER_USER_APP_BETA_NOTICE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 391
    DISMISSIBLE_CONTENT_COLLECTIBLES_PIRATES_MOBILE_BADGING: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 392
    DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_RETRO_AND_PIRATES_COACHTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 393
    DISMISSIBLE_CONTENT_PRIDE_ICONS: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 394
    DISMISSIBLE_CONTENT_PRIDE_ICONS_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 395
    DISMISSIBLE_CONTENT_PRIDE_ICONS_APPEARANCE_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 396
    DISMISSIBLE_CONTENT_CLAN_TAG_WAITLIST: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 397
    DISMISSIBLE_CONTENT_GUILD_LIST_CLAN_USER_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 398
    DISMISSIBLE_CONTENT_QUEST_HOME_FRIENDS_LIST_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 399
    DISMISSIBLE_CONTENT_WHATS_NEW_APP_STYLES_JUNE_2024_FLIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 400
    DISMISSIBLE_CONTENT_WHATS_NEW_CUSTOM_NOTIFICATION_SOUNDS_FLIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 401
    DISMISSIBLE_CONTENT_WHATS_NEW_REFERRAL_PROGRAM_FLIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 402
    DISMISSIBLE_CONTENT_WHATS_NEW_APP_STYLES_JUNE_2024_NITRO_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 403
    DISMISSIBLE_CONTENT_WHATS_NEW_CUSTOM_NOTIFICATION_SOUNDS_NITRO_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 404
    DISMISSIBLE_CONTENT_WHATS_NEW_REFERRAL_PROGRAM_NITRO_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 405
    DISMISSIBLE_CONTENT_WHATS_NEW_SERVER_PROFILE_FLIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 406
    DISMISSIBLE_CONTENT_WHATS_NEW_SERVER_PROFILE_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 407
    DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_ARCADE_COACHTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 408
    DISMISSIBLE_CONTENT_CHECKOUT_RECOVERY_NAGBAR: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 409
    DISMISSIBLE_CONTENT_PREMIUM_2024_JUNE_MARKETING_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 410
    DISMISSIBLE_CONTENT_APP_LAUNCHER_GLOBAL_SEARCH_ONBOARDING: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 411
    DISMISSIBLE_CONTENT_NEW_GAMING_DISCOVERY_NOTIF: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 412
    DISMISSIBLE_CONTENT_NITRO_ON_PROFILE_SIDE_PANEL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 414
    DISMISSIBLE_CONTENT_MESSAGE_FORWARDING_DESKTOP_UTILITIES_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 415
    DISMISSIBLE_CONTENT_MESSAGE_FORWARDING_MOBILE_SHEET_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 416
    DISMISSIBLE_CONTENT_SUMMER_2024_BOGO_ANNOUNCEMENT_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 417
    DISMISSIBLE_CONTENT_GIFT_INVENTORY_QUESTS_MOVED_TO_QUEST_HOME: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 421
    DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_ENTRY_MARKETING: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 422
    DISMISSIBLE_CONTENT_CASH_APP_PAY_AWARENESS_NAGBAR: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 423
    DISMISSIBLE_CONTENT_ICYMI_ALPHA_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 425
    DISMISSIBLE_CONTENT_PASSWORDLESS_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 427
    DISMISSIBLE_CONTENT_CHANNEL_LINKED_LOBBY_EDUCATION_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 429
    DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_DOJO_MARKETING: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 431
    DISMISSIBLE_CONTENT_REVERSE_TRIAL_STREAM_POPOUT: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 432
    DISMISSIBLE_CONTENT_REVERSE_TRIAL_NITRO_TAB_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 433
    DISMISSIBLE_CONTENT_REVERSE_TRIAL_EMOJI_BUTTON: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 434
    DISMISSIBLE_CONTENT_REVERSE_TRIAL_FIRST_IMPRESSION_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 435
    DISMISSIBLE_CONTENT_REVERSE_TRIAL_EMOJI_PICKER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 436
    DISMISSIBLE_CONTENT_REVERSE_TRIAL_ENDED_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 437
    DISMISSIBLE_CONTENT_VOICE_PANEL_ACTIVITIES_SHAPES_BUTTON_EDUCATION_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 439
    DISMISSIBLE_CONTENT_FOR_LATER_NOTIFICATIONS_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 440
    DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_THE_VAULT_MARKETING: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 441
    DISMISSIBLE_CONTENT_USER_DM_MUTE_FEEDBACK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 442
    DISMISSIBLE_CONTENT_RAPIDASH_M3_DISCOVERY_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 443
    DISMISSIBLE_CONTENT_WHATS_NEW_TENURE_BADGE_REWARD: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 444
    DISMISSIBLE_CONTENT_FOR_LATER_POPOUT_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 445
    DISMISSIBLE_CONTENT_GLOBAL_DISCOVERY_RAPIDASH_NOTIF: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 448
    DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_BAND_MARKETING: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 449
    DISMISSIBLE_CONTENT_RAPIDASH_MORE_GUILDS_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 452
    DISMISSIBLE_CONTENT_TRIAL_FOR_ALL_INITIAL_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 453
    DISMISSIBLE_CONTENT_TRIAL_FOR_ALL_MOBILE_SETTINGS_NOTICE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 454
    DISMISSIBLE_CONTENT_RAPIDASH_RTC_BROWSE_GUILDS: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 456
    DISMISSIBLE_CONTENT_TRIAL_FOR_ALL_MARKETING_PAGE_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 457
    DISMISSIBLE_CONTENT_USER_PROFILE_PREMIUM_AND_SHOP_ENTRY_POINTS: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 458
    DISMISSIBLE_CONTENT_TRIAL_FOR_ALL_DESKTOP_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 462
    DISMISSIBLE_CONTENT_GIFTING_PROMOTION_ICON: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 467
    DISMISSIBLE_CONTENT_GIFTING_PROMOTION_DESKTOP_FIRST_TIME_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 468
    DISMISSIBLE_CONTENT_GIFTING_PROMOTION_MOBILE_FIRST_TIME_HALFSHEET: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 469
    DISMISSIBLE_CONTENT_GIFTING_PROMOTION_REMINDER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 470
    DISMISSIBLE_CONTENT_CONSUMABLE_HD_POTION_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 471
    DISMISSIBLE_CONTENT_HD_STREAMING_POTION_MODAL_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 472
    DISMISSIBLE_CONTENT_HD_STREAMING_POTION_BANNER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 473
    DISMISSIBLE_CONTENT_GIFTING_INTENT_FRIENDS_TAB_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 474
    DISMISSIBLE_CONTENT_FRACTIONAL_NITRO_DURATION_LEFT_PILL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 476
    DISMISSIBLE_CONTENT_RESTRICTED_ACCOUNTS_SETTING_NOTICE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 479
    DISMISSIBLE_CONTENT_CONNECTIONS_XBOX_LINK_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 480
    DISMISSIBLE_CONTENT_CONNECTIONS_NEW_CONSOLE_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 481
    DISMISSIBLE_CONTENT_REFERRAL_TRIAL_MOBILE_NITRO_HOME_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 482
    DISMISSIBLE_CONTENT_SOUNDMOJI_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 483
    DISMISSIBLE_CONTENT_SOUNDMOJI_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 484
    DISMISSIBLE_CONTENT_REFERRAL_TRIAL_MOBILE_SENDER_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 485
    DISMISSIBLE_CONTENT_TRIAL_NUX_EMOJI_BUTTON: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 486
    DISMISSIBLE_CONTENT_TRIAL_NUX_EMOJI_PICKER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 487
    DISMISSIBLE_CONTENT_TRIAL_NUX_STREAM_COACH_MARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 488
    DISMISSIBLE_CONTENT_TIERED_TENURE_BADGE_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 491
    DISMISSIBLE_CONTENT_VIRTUAL_CURRENCY_ONBOARDING_ANNOUNCEMENT_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 492
    DISMISSIBLE_CONTENT_CONFETTI_POTION_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 494
    DISMISSIBLE_CONTENT_SHARE_ACTIVITY_COACHMARK_V2: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 496
    DISMISSIBLE_CONTENT_VOICE_FILTER_LOOPBACK_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 497
    DISMISSIBLE_CONTENT_VOICE_FILTER_LAUNCH_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 498
    DISMISSIBLE_CONTENT_VOICE_FILTER_IN_CALL_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 499
    DISMISSIBLE_CONTENT_REVERSE_TRIAL_NITRO_TAB_BADGE_V2: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 500
    DISMISSIBLE_CONTENT_OVERLAY_OOP_WELCOME_NUX: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 501
    DISMISSIBLE_CONTENT_OVERLAY_OOP_WELCOME_SWITCH_FROM_IP_NUX: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 502
    DISMISSIBLE_CONTENT_OVERLAY_OOP_WELCOME_BACKGROUND_NUX: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 503
    DISMISSIBLE_CONTENT_OVERLAY_OOP_WELCOME_BACKGROUND_SWITCH_FROM_IP_NUX: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 504
    DISMISSIBLE_CONTENT_OVERLAY_OOP_SETTINGS_NUX: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 505
    DISMISSIBLE_CONTENT_Q1_2025_REVERSE_TRIAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 506
    DISMISSIBLE_CONTENT_Q1_2025_FOLLOW_UP_REVERSE_TRIAL_OFFER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 507
    DISMISSIBLE_CONTENT_GUILD_POWERUPS_OVERVIEW_SIDEBAR_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 508
    DISMISSIBLE_CONTENT_SWIPE_TO_MEMBER_LIST_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 512
    DISMISSIBLE_CONTENT_VIRTUAL_CURRENCY_DISCOVERY_ONBOARDING_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 513
    DISMISSIBLE_CONTENT_VIRTUAL_CURRENCY_SHOP_ONBOARDING_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 514
    DISMISSIBLE_CONTENT_CLICKER_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 515
    DISMISSIBLE_CONTENT_RECENT_AVATARS_SETTINGS_MENU_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 516
    DISMISSIBLE_CONTENT_RECENT_AVATARS_SETTINGS_PROFILE_PAGE_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 517
    DISMISSIBLE_CONTENT_PERMADECOS_NITRO_TAB_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 518
    DISMISSIBLE_CONTENT_PERMADECOS_NITRO_HOME_CARD_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 520
    DISMISSIBLE_CONTENT_RING_USER_TO_VC_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 522
    DISMISSIBLE_CONTENT_DESKTOP_REFRESH_ONBOARDING_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 525
    DISMISSIBLE_CONTENT_GUILD_POWERUP_NOTIFICATION: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 529
    DISMISSIBLE_CONTENT_GUILD_TAG_AVAILABLE_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 530
    DISMISSIBLE_CONTENT_GUILD_POWERUP_PERKS_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 531
    DISMISSIBLE_CONTENT_THIRD_PARTY_OUTBOUND_PROMO_NAGBAR: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 532
    DISMISSIBLE_CONTENT_GUILD_TAG_USER_PROFILE_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 534
    DISMISSIBLE_CONTENT_GUILD_TAG_SERVER_SETTINGS_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 535
    DISMISSIBLE_CONTENT_GUILD_SETTINGS_ROLE_STYLES_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 536
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_IGNORE_USER_FEEDBACK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 537
    DISMISSIBLE_CONTENT_REPORT_TO_MOD_SURVEY_NOTICE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 538
    DISMISSIBLE_CONTENT_Q2_2025_MARKETING_MOMENT_NITRO_TAB_BADGE_V2: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 539
    DISMISSIBLE_CONTENT_Q2_2025_MARKETING_MOMENT_FIRST_IMPRESSION_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 540
    DISMISSIBLE_CONTENT_Q2_2025_MARKETING_MOMENT_FOLLOW_UP_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 541
    DISMISSIBLE_CONTENT_REPORT_TO_MOD_NEW_TAG: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 542
    DISMISSIBLE_CONTENT_NITRO_TENURE_BADGE_LEVEL_UP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 544
    DISMISSIBLE_CONTENT_ROBLOX_CONNECTION_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 545
    DISMISSIBLE_CONTENT_VOICE_FILTER_FIRST_USE_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 546
    DISMISSIBLE_CONTENT_CHANNEL_REORDER_MODAL_DISMISS_SETTING: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 547
    DISMISSIBLE_CONTENT_CUSTOM_THEME_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 548
    DISMISSIBLE_CONTENT_VOICE_FILTER_EARLY_ACCESS_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 549
    DISMISSIBLE_CONTENT_VOICE_FILTER_EARLY_ACCESS_PREMIUM_TAB_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 550
    DISMISSIBLE_CONTENT_CLIENT_THEMES_APPEARANCE_SETTINGS_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 551
    DISMISSIBLE_CONTENT_CUSTOM_THEME_ENTRYPOINT_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 552
    DISMISSIBLE_CONTENT_MOBILE_BOGO_PROMOTION_ACTION_SHEET: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 553
    DISMISSIBLE_CONTENT_CUSTOM_THEME_ENTRYPOINT_GRADIENT: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 554
    DISMISSIBLE_CONTENT_TIERLESS_BOOSTING_SYSTEM_MESSAGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 555
    DISMISSIBLE_CONTENT_GOOGLE_PLAY_PRICE_CHANGE_ACTION_SHEET: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 556
    DISMISSIBLE_CONTENT_REFERRAL_PROGRAM_NITRO_TAB_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 557
    DISMISSIBLE_CONTENT_ACTIVITIES_VOICE_LAUNCHER_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 558
    DISMISSIBLE_CONTENT_BOGO_2025_NITRO_TAB_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 559
    DISMISSIBLE_CONTENT_BOGO_2025_ANNOUNCEMENT_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 560
    DISMISSIBLE_CONTENT_NITRO_PRIVATE_BROWSING_SURVEY: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 563
    DISMISSIBLE_CONTENT_GUILD_POWERUP_NEW_PERK_AVAILABLE_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 564
    DISMISSIBLE_CONTENT_VANITY_URL_POWERUP_EDUCATIONAL_POPOVER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 565
    DISMISSIBLE_CONTENT_AGE_VERIFICATION_SURVEY_MODAL_CLOSE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 566
    DISMISSIBLE_CONTENT_AGE_VERIFICATION_SURVEY_MODAL_GET_STARTED: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 567
    DISMISSIBLE_CONTENT_GUILD_PIN_PERMISSION_MIGRATION_NOTIFICATION: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 568
    DISMISSIBLE_CONTENT_VANITY_URL_POWERUP_ROLLBACK_NOTIFICATION: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 569
    DISMISSIBLE_CONTENT_VANITY_URL_POWERUP_ROLLBACK_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 570
    DISMISSIBLE_CONTENT_VIRTUAL_CURRENCY_DISCOVERY_REHEAT_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 571
    DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 572
    DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 573
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_OFFER_EXPIRING: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 574
    DISMISSIBLE_CONTENT_SEARCH_AUTHOR_TYPE_FILTER_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 575
    DISMISSIBLE_CONTENT_SEARCH_AUTHOR_TYPE_SEARCH_RESULTS_HINT: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 576
    DISMISSIBLE_CONTENT_REFERRAL_PROGRAM_POPOVER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 577
    DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_NEW_BADGE_PROFILE_PAGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 579
    DISMISSIBLE_CONTENT_CLOUD_PLAY_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 580
    DISMISSIBLE_CONTENT_ACCESSIBILITY_HIGH_CONTRAST_MODE_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 583
    DISMISSIBLE_CONTENT_WIDGETS_RTC_UPSELL_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 584
    DISMISSIBLE_CONTENT_CLOUD_PLAY_POPOVER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 585
    DISMISSIBLE_CONTENT_CUSTOM_THEMES_NITRO_HOME_TILE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 586
    DISMISSIBLE_CONTENT_GUILD_HEADER_BOOST_PROGRESS_BAR_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 587
    DISMISSIBLE_CONTENT_WIDGETS_USER_SETTINGS_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 588
    DISMISSIBLE_CONTENT_WIDGETS_USER_SETTINGS_PROFILE_PAGE_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 589
    DISMISSIBLE_CONTENT_CHURN_DISCOUNT_PREMIUM_TAB_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 591
    DISMISSIBLE_CONTENT_CHURN_DISCOUNT_PREMIUM_TAB_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 592
    DISMISSIBLE_CONTENT_DOUBLE_TAP_TO_REACT_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 593
    DISMISSIBLE_CONTENT_NITRO_DROP_REWARD: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 594
    DISMISSIBLE_CONTENT_SEPTEMBER_2025_MARKETING_MOMENT_NITRO_TAB_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 595
    DISMISSIBLE_CONTENT_SEPTEMBER_2025_MARKETING_MOMENT_NITRO_TAB_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 596
    DISMISSIBLE_CONTENT_DOUBLE_TAP_TO_REACT_REMINDER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 597
    DISMISSIBLE_CONTENT_VIRTUAL_CURRENCY_MOBILE_ONBOARDING_ANNOUNCEMENT_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 598
    DISMISSIBLE_CONTENT_SEPTEMBER_MARKETING_MOMENT_ANNOUNCEMENT_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 599
    DISMISSIBLE_CONTENT_DO_NOT_DISTURB_REMINDER_POPOVER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 600
    DISMISSIBLE_CONTENT_ACCOUNT_LINK_INVITE_FRIENDS: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 601
    DISMISSIBLE_CONTENT_POST_ACCOUNT_CONNECTION_RTC_POPOVER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 602
    DISMISSIBLE_CONTENT_HALLOWEEN_APP_ICONS_APPEARANCE_SETTINGS_WEB_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 603
    DISMISSIBLE_CONTENT_HALLOWEEN_APP_ICONS_APPEARANCE_SETTINGS_MOBILE_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 604
    DISMISSIBLE_CONTENT_HALLOWEEN_APP_ICONS_TRICK_ICON_WEB_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 605
    DISMISSIBLE_CONTENT_HALLOWEEN_APP_ICONS_TREAT_ICON_WEB_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 606
    DISMISSIBLE_CONTENT_NOTIFICATION_NUDGE_DM_HOME_BANNER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 607
    DISMISSIBLE_CONTENT_NOTIFICATION_NUDGE_CHAT_BOTTOM_BANNER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 608
    DISMISSIBLE_CONTENT_NOTIFICATION_NUDGE_APP_START_BOTTOM_SHEET: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 609
    DISMISSIBLE_CONTENT_ACCOUNT_LINK_PROMPT: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 610
    DISMISSIBLE_CONTENT_WISHLIST_NUX_TOOLTIP_AND_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 611
    DISMISSIBLE_CONTENT_WIDGETS_USER_PROFILE_ACCOUNT_POPOUT_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 613
    DISMISSIBLE_CONTENT_GAME_SERVER_HOSTING_PORTKEY_TOS: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 614
    DISMISSIBLE_CONTENT_APPLICATION_WIDGET_EDIT_PROFILE_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 615
    DISMISSIBLE_CONTENT_APPLICATION_WIDGET_EDIT_PROFILE_POPOVER_LINKED: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 616
    DISMISSIBLE_CONTENT_APPLICATION_WIDGET_EDIT_PROFILE_POPOVER_UNLINKED: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 617
    DISMISSIBLE_CONTENT_APPLICATION_WIDGET_EMPTY_STATE_CARD_CONNECT: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 618
    DISMISSIBLE_CONTENT_APPLICATION_WIDGET_EMPTY_STATE_CARD_ADD_WIDGET: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 619
    DISMISSIBLE_CONTENT_GAME_SERVER_HOSTING_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 620
    DISMISSIBLE_CONTENT_WISHLIST_SHOP_BUTTON_POPOVER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 621
    DISMISSIBLE_CONTENT_HANG_STATUS_POPOVER_NUX: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 622
    DISMISSIBLE_CONTENT_REPORT_TO_MOD_EXIT_SURVEY_NOTICE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 623
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_PASSKEY_BACKUP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 624
    DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_NITRO_HOME_TILE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 625
    DISMISSIBLE_CONTENT_CROSS_DM_SEARCH_SETTING_EDUCATION_POPOVER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 627
    DISMISSIBLE_CONTENT_NITRO_TAB_BADGE_COUNTDOWN: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 630
    DISMISSIBLE_CONTENT_HOLIDAY_COACHMARK_HALLOWEEN_2025: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 631
    DISMISSIBLE_CONTENT_QUEST_HOME_ENTRYPOINT_ONBOARDING: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 632
    DISMISSIBLE_CONTENT_PREMIUM_MARKETING_MOMENT_ANNOUNCEMENT_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 633
    DISMISSIBLE_CONTENT_NITRO_TAB_BADGE_OFFER_REMINDER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 634
    DISMISSIBLE_CONTENT_VIRTUAL_CURRENCY_MOBILE_ONBOARDING_PILL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 635
    DISMISSIBLE_CONTENT_GAME_WIDGETS_USER_PROFILE_ACCOUNT_POPOUT_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 636
    DISMISSIBLE_CONTENT_RECURRING_3P_PROMOTION_POPOVER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 637
    DISMISSIBLE_CONTENT_PREMIUM_TAB_MARKETING_MOMENT_OFFER_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 638
    DISMISSIBLE_CONTENT_GAME_SERVER_HOSTING_NEW_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 639
    DISMISSIBLE_CONTENT_GAME_SHOP_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 640
    DISMISSIBLE_CONTENT_GAME_SHOP_RTC_POPOVER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 641
    DISMISSIBLE_CONTENT_GUILD_JOINT_PERMISSION_MIGRATION_NOTIFICATION: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 642
    DISMISSIBLE_CONTENT_GAME_SHOP_ANNOUNCEMENT_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 643
    DISMISSIBLE_CONTENT_CHECKPOINT_2025_BOTTOM_SHEET: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 644
    DISMISSIBLE_CONTENT_GAME_SHOP_WISHLIST_POPOVER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 645
    DISMISSIBLE_CONTENT_DISCOUNT_OFFER_ACTION_SHEET: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 646
    DISMISSIBLE_CONTENT_MOBILE_PREMIUM_TRIAL_OFFER_ACTION_SHEET: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 647
    DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_MOBILE_ANNOUNCEMENT_MODAL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 648
    DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_MOBILE_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 649
    DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_WIDE_BANNER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 650
    DISMISSIBLE_CONTENT_NITRO_PRIVACY_PERK_BETA_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 651
    DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_MOBILE_PROFILE_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 653
    DISMISSIBLE_CONTENT_CHECKPOINT_2025_DESKTOP_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 654
    DISMISSIBLE_CONTENT_APPLICATION_WIDGET_WUWA_SUGGESTED_WIDGET: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 655
    DISMISSIBLE_CONTENT_APPLICATION_WIDGET_WUWA_EDIT_PROFILE_POPOVER_LINKED: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 656
    DISMISSIBLE_CONTENT_APPLICATION_WIDGET_WUWA_EDIT_PROFILE_POPOVER_UNLINKED: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 657
    DISMISSIBLE_CONTENT_INSTALLED_GAME_COMMUNITY_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 658
    DISMISSIBLE_CONTENT_GAME_SHOP_RTC_GIFTING_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 659
    DISMISSIBLE_CONTENT_GAME_INVITE_ACCOUNT_LINK_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 660
    DISMISSIBLE_CONTENT_NITRO_PRIVACY_PERK_NEW_BADGE_V2: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 661
    DISMISSIBLE_CONTENT_GUILD_TAG_AVAILABLE_COACHMARK_V2: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 662
    DISMISSIBLE_CONTENT_GUILD_TAG_UPDATED_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 663
    DISMISSIBLE_CONTENT_ORB_RENTAL_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 664
    DISMISSIBLE_CONTENT_HOLIDAY_COACHMARK_WINTER_2025: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 665
    DISMISSIBLE_CONTENT_WISHLIST_USER_PROFILE_ACCOUNT_POPOUT_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 666
    DISMISSIBLE_CONTENT_TRIAL_FOR_ALL_2026_SETTINGS_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 667
    DISMISSIBLE_CONTENT_PREMIUM_GROUP_POPOVER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 668
    DISMISSIBLE_CONTENT_PREMIUM_ORBS_UPSELL_POPOVER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 669
    DISMISSIBLE_CONTENT_PREMIUM_ORBS_REWARDS_DROP_POPOVER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 670
    DISMISSIBLE_CONTENT_GAME_SERVER_HOSTING_NEW_PERK_AVAILABLE_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 672
    DISMISSIBLE_CONTENT_PREMIUM_ORBS_REWARDS_INTRO_POPOVER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 673
    DISMISSIBLE_CONTENT_BOOST_PROGRESS_BAR_ADMIN_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 674
    DISMISSIBLE_CONTENT_BOOST_PROGRESS_BAR_MEMBER_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 675
    DISMISSIBLE_CONTENT_QUEST_HOME_ENTRYPOINT_TAKEOVER_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 676
    DISMISSIBLE_CONTENT_SLAYER_STOREFRONT_XBOX_ANNOUNCEMENT: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 677
    DISMISSIBLE_CONTENT_BOOST_TO_UNLOCK_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 678
    DISMISSIBLE_CONTENT_WISHLIST_MOBILE_NUX_PRODUCT_CARD_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 679
    DISMISSIBLE_CONTENT_WISHLIST_MOBILE_NUX_ACTION_SHEET: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 680
    DISMISSIBLE_CONTENT_WISHLIST_MOBILE_YOU_SCREEN_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 681
    DISMISSIBLE_CONTENT_GAME_CLAIM_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 682
    DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_MARVEL_RIVALS_ORBS_REWARD: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 683
    DISMISSIBLE_CONTENT_EXPIRING_POWERUP_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 684
    DISMISSIBLE_CONTENT_FIRST_BOOSTER_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 685
    DISMISSIBLE_CONTENT_REFERRAL_PROGRAM_POPOVER_V2: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 686
    DISMISSIBLE_CONTENT_QUEST_HOME_ENTRYPOINT_HERO_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 687
    DISMISSIBLE_CONTENT_GAME_DETECTION_CREATE_GAME_SERVER_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 688
    DISMISSIBLE_CONTENT_GAME_DETECTION_CREATE_GAME_SERVER_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 689
    DISMISSIBLE_CONTENT_JOIN_GAME_COMMUNITY_RTC_CTA: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 690
    DISMISSIBLE_CONTENT_NAGBAR_QUEST_APP_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 691
    DISMISSIBLE_CONTENT_GAME_SHOP_ORBS_REWARD_BANNER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 692
    DISMISSIBLE_CONTENT_SLAYER_STOREFRONT_ORBS_REWARDS_ANNOUNCEMENT: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 693
    DISMISSIBLE_CONTENT_FAVORITES_SERVER_ONBOARDING_INTRO: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 694
    DISMISSIBLE_CONTENT_FAVORITES_SERVER_ONBOARDING_MENU_ITEM: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 695
    DISMISSIBLE_CONTENT_GIFT_INTENT_MESSAGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 696
    DISMISSIBLE_CONTENT_MOBILE_REFERRAL_PROGRAM_BOTTOM_SHEET_ENTRYPOINT: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 697
    DISMISSIBLE_CONTENT_GAME_ACCOUNT_LINK_RECURRING_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 698
    DISMISSIBLE_CONTENT_WISHLIST_MOBILE_VIEWER_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 699
    DISMISSIBLE_CONTENT_EMPTY_GAME_SERVER_TAB: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 700
    DISMISSIBLE_CONTENT_GUILD_POWERUPS_OVERVIEW_SIDEBAR_VIDEO_CARD: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 701
    DISMISSIBLE_CONTENT_SLAYER_STOREFRONT_ORBS_REWARD_WISHLIST_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 702
    DISMISSIBLE_CONTENT_USER_PROFILE_WISHLIST_RECOMMENDATIONS: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 703
    DISMISSIBLE_CONTENT_GAME_SERVER_HOSTING_BATCH_RELEASE_V2_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 704
    DISMISSIBLE_CONTENT_QUEST_ACTIVITY_HEADER_INTRO: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 705
    DISMISSIBLE_CONTENT_GAME_SERVER_GAME_DETECTION_UPSELL_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 706
    DISMISSIBLE_CONTENT_REFERRAL_PROGRAM_ENTRYPOINT_NITRO_TAB_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 707
    DISMISSIBLE_CONTENT_DOUBLE_TAP_TO_REACT_EXPANDED_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 708
    DISMISSIBLE_CONTENT_FAVORITES_GUILD_NEW_BADGE: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 709
    DISMISSIBLE_CONTENT_FIRST_BOOSTER_UPSELL_OVERSEER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 710
    DISMISSIBLE_CONTENT_MOBILE_MULTI_GUILD_CREATE_UPSELL_ANIMATION: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 711
    DISMISSIBLE_CONTENT_PREMIUM_MARKETING_MOMENT_REMINDER_UPSELL: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 712
    DISMISSIBLE_CONTENT_GAME_SERVER_PRICING_CHANGE_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 713
    DISMISSIBLE_CONTENT_PREMIUM_WISHLIST_COACHMARK: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 714
    DISMISSIBLE_CONTENT_PREMIUM_GROUP_POPOVER_UPSELL_V2: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 715
    DISMISSIBLE_CONTENT_L_3PP_NON_NITRO_POPOVER: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 716
    DISMISSIBLE_CONTENT_L_3PP_NITRO_TOOLTIP: PremiumMarketingComponentProperties.DismissibleContent.ValueType  # 717

    @_typing.final
    class FeatureCard(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        HEADER_FIELD_NUMBER: _builtins.int
        PILL_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        IMAGE_LINK_FIELD_NUMBER: _builtins.int
        IMAGE_LINK_LIGHT_THEME_FIELD_NUMBER: _builtins.int
        header: _builtins.str
        pill: _builtins.str
        body: _builtins.str
        image_link: _builtins.str
        image_link_light_theme: _builtins.str
        def __init__(
            self,
            *,
            header: _builtins.str = ...,
            pill: _builtins.str = ...,
            body: _builtins.str = ...,
            image_link: _builtins.str = ...,
            image_link_light_theme: _builtins.str = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["body", b"body", "header", b"header", "image_link", b"image_link", "image_link_light_theme", b"image_link_light_theme", "pill", b"pill"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class SubscriptionButton(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        COPY_FIELD_NUMBER: _builtins.int
        BUTTON_ACTION_FIELD_NUMBER: _builtins.int
        copy: _builtins.str
        button_action: Global___PremiumMarketingComponentProperties.ButtonAction.ValueType
        def __init__(
            self,
            *,
            copy: _builtins.str = ...,
            button_action: Global___PremiumMarketingComponentProperties.ButtonAction.ValueType = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["button_action", b"button_action", "copy", b"copy"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class Subtitle(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        LINK_FIELD_NUMBER: _builtins.int
        LOCALE_FIELD_NUMBER: _builtins.int
        IS_DEFAULT_FIELD_NUMBER: _builtins.int
        link: _builtins.str
        locale: _builtins.str
        is_default: _builtins.bool
        def __init__(
            self,
            *,
            link: _builtins.str = ...,
            locale: _builtins.str = ...,
            is_default: _builtins.bool = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["is_default", b"is_default", "link", b"link", "locale", b"locale"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class Variant1Storage(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        @_typing.final
        class HeroArtLocalizedVideoLinksDarkThemeEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.str
            value: _builtins.str
            def __init__(
                self,
                *,
                key: _builtins.str = ...,
                value: _builtins.str = ...,
            ) -> None: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        @_typing.final
        class HeroArtLocalizedVideoLinksLightThemeEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.str
            value: _builtins.str
            def __init__(
                self,
                *,
                key: _builtins.str = ...,
                value: _builtins.str = ...,
            ) -> None: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        @_typing.final
        class HeroArtVideoSubtitleLinksEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.str
            value: _builtins.str
            def __init__(
                self,
                *,
                key: _builtins.str = ...,
                value: _builtins.str = ...,
            ) -> None: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        HERO_ART_LOCALIZED_VIDEO_LINKS_DARK_THEME_FIELD_NUMBER: _builtins.int
        HERO_ART_LOCALIZED_VIDEO_LINKS_LIGHT_THEME_FIELD_NUMBER: _builtins.int
        HERO_ART_VIDEO_SUBTITLE_LINKS_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def hero_art_localized_video_links_dark_theme(self) -> _containers.ScalarMap[_builtins.str, _builtins.str]: ...
        @_builtins.property
        def hero_art_localized_video_links_light_theme(self) -> _containers.ScalarMap[_builtins.str, _builtins.str]: ...
        @_builtins.property
        def hero_art_video_subtitle_links(self) -> _containers.ScalarMap[_builtins.str, _builtins.str]: ...
        def __init__(
            self,
            *,
            hero_art_localized_video_links_dark_theme: _abc.Mapping[_builtins.str, _builtins.str] | None = ...,
            hero_art_localized_video_links_light_theme: _abc.Mapping[_builtins.str, _builtins.str] | None = ...,
            hero_art_video_subtitle_links: _abc.Mapping[_builtins.str, _builtins.str] | None = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["hero_art_localized_video_links_dark_theme", b"hero_art_localized_video_links_dark_theme", "hero_art_localized_video_links_light_theme", b"hero_art_localized_video_links_light_theme", "hero_art_video_subtitle_links", b"hero_art_video_subtitle_links"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class AnnouncementModalVariant1Properties(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        HEADER_FIELD_NUMBER: _builtins.int
        SUBHEADER_FIELD_NUMBER: _builtins.int
        VIDEO_LINK_FIELD_NUMBER: _builtins.int
        HELP_ARTICLE_ID_FIELD_NUMBER: _builtins.int
        FEATURE_CARDS_FIELD_NUMBER: _builtins.int
        BUTTON_FIELD_NUMBER: _builtins.int
        DISMISS_KEY_FIELD_NUMBER: _builtins.int
        HERO_ART_VIDEO_LINK_LIGHT_THEME_FIELD_NUMBER: _builtins.int
        HERO_ART_IMAGE_LINK_DARK_THEME_FIELD_NUMBER: _builtins.int
        HERO_ART_IMAGE_LINK_LIGHT_THEME_FIELD_NUMBER: _builtins.int
        MODAL_TOP_PILL_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        HERO_ART_VIDEO_SUBTITLES_FIELD_NUMBER: _builtins.int
        STORAGE_FIELD_NUMBER: _builtins.int
        header: _builtins.str
        subheader: _builtins.str
        video_link: _builtins.str
        help_article_id: _builtins.str
        dismiss_key: _builtins.str
        hero_art_video_link_light_theme: _builtins.str
        hero_art_image_link_dark_theme: _builtins.str
        hero_art_image_link_light_theme: _builtins.str
        modal_top_pill: _builtins.str
        body: _builtins.str
        @_builtins.property
        def feature_cards(self) -> _containers.RepeatedCompositeFieldContainer[Global___PremiumMarketingComponentProperties.FeatureCard]: ...
        @_builtins.property
        def button(self) -> Global___PremiumMarketingComponentProperties.SubscriptionButton: ...
        @_builtins.property
        def hero_art_video_subtitles(self) -> _containers.RepeatedCompositeFieldContainer[Global___PremiumMarketingComponentProperties.Subtitle]: ...
        @_builtins.property
        def storage(self) -> Global___PremiumMarketingComponentProperties.Variant1Storage: ...
        def __init__(
            self,
            *,
            header: _builtins.str = ...,
            subheader: _builtins.str = ...,
            video_link: _builtins.str = ...,
            help_article_id: _builtins.str = ...,
            feature_cards: _abc.Iterable[Global___PremiumMarketingComponentProperties.FeatureCard] | None = ...,
            button: Global___PremiumMarketingComponentProperties.SubscriptionButton | None = ...,
            dismiss_key: _builtins.str = ...,
            hero_art_video_link_light_theme: _builtins.str = ...,
            hero_art_image_link_dark_theme: _builtins.str = ...,
            hero_art_image_link_light_theme: _builtins.str = ...,
            modal_top_pill: _builtins.str = ...,
            body: _builtins.str = ...,
            hero_art_video_subtitles: _abc.Iterable[Global___PremiumMarketingComponentProperties.Subtitle] | None = ...,
            storage: Global___PremiumMarketingComponentProperties.Variant1Storage | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_button", b"_button", "_storage", b"_storage", "button", b"button", "storage", b"storage"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_button", b"_button", "_storage", b"_storage", "body", b"body", "button", b"button", "dismiss_key", b"dismiss_key", "feature_cards", b"feature_cards", "header", b"header", "help_article_id", b"help_article_id", "hero_art_image_link_dark_theme", b"hero_art_image_link_dark_theme", "hero_art_image_link_light_theme", b"hero_art_image_link_light_theme", "hero_art_video_link_light_theme", b"hero_art_video_link_light_theme", "hero_art_video_subtitles", b"hero_art_video_subtitles", "modal_top_pill", b"modal_top_pill", "storage", b"storage", "subheader", b"subheader", "video_link", b"video_link"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__button: _TypeAlias = _typing.Literal["button"]  # noqa: Y015
        _WhichOneofArgType__button: _TypeAlias = _typing.Literal["_button", b"_button"]  # noqa: Y015
        _WhichOneofReturnType__storage: _TypeAlias = _typing.Literal["storage"]  # noqa: Y015
        _WhichOneofArgType__storage: _TypeAlias = _typing.Literal["_storage", b"_storage"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__button) -> _WhichOneofReturnType__button | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__storage) -> _WhichOneofReturnType__storage | None: ...

    @_typing.final
    class PremiumTab(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        BADGE_LABEL_FIELD_NUMBER: _builtins.int
        ACKNOWLEDGED_BADGE_LABEL_FIELD_NUMBER: _builtins.int
        badge_label: _builtins.str
        acknowledged_badge_label: _builtins.str
        def __init__(
            self,
            *,
            badge_label: _builtins.str = ...,
            acknowledged_badge_label: _builtins.str = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["acknowledged_badge_label", b"acknowledged_badge_label", "badge_label", b"badge_label"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class MarketingPageBannerButton(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        COPY_FIELD_NUMBER: _builtins.int
        BUTTON_ACTION_FIELD_NUMBER: _builtins.int
        copy: _builtins.str
        button_action: Global___PremiumMarketingComponentProperties.ButtonAction.ValueType
        def __init__(
            self,
            *,
            copy: _builtins.str = ...,
            button_action: Global___PremiumMarketingComponentProperties.ButtonAction.ValueType = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["button_action", b"button_action", "copy", b"copy"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class MarketingPageBanner(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ASSET_URL_FIELD_NUMBER: _builtins.int
        HEADER_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        HELP_ARTICLE_ID_FIELD_NUMBER: _builtins.int
        BUTTON_FIELD_NUMBER: _builtins.int
        asset_url: _builtins.str
        header: _builtins.str
        body: _builtins.str
        help_article_id: _builtins.str
        @_builtins.property
        def button(self) -> Global___PremiumMarketingComponentProperties.MarketingPageBannerButton: ...
        def __init__(
            self,
            *,
            asset_url: _builtins.str = ...,
            header: _builtins.str = ...,
            body: _builtins.str = ...,
            help_article_id: _builtins.str = ...,
            button: Global___PremiumMarketingComponentProperties.MarketingPageBannerButton | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_button", b"_button", "button", b"button"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_button", b"_button", "asset_url", b"asset_url", "body", b"body", "button", b"button", "header", b"header", "help_article_id", b"help_article_id"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__button: _TypeAlias = _typing.Literal["button"]  # noqa: Y015
        _WhichOneofArgType__button: _TypeAlias = _typing.Literal["_button", b"_button"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__button) -> _WhichOneofReturnType__button | None: ...

    @_typing.final
    class PaymentModalBanner(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ASSET_URL_FIELD_NUMBER: _builtins.int
        HEADER_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        asset_url: _builtins.str
        header: _builtins.str
        body: _builtins.str
        def __init__(
            self,
            *,
            asset_url: _builtins.str = ...,
            header: _builtins.str = ...,
            body: _builtins.str = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["asset_url", b"asset_url", "body", b"body", "header", b"header"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class CTAButton(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        COPY_FIELD_NUMBER: _builtins.int
        BUTTON_ACTION_FIELD_NUMBER: _builtins.int
        copy: _builtins.str
        button_action: Global___PremiumMarketingComponentProperties.ButtonAction.ValueType
        def __init__(
            self,
            *,
            copy: _builtins.str = ...,
            button_action: Global___PremiumMarketingComponentProperties.ButtonAction.ValueType = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["button_action", b"button_action", "copy", b"copy"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class MobileBottomSheet(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ASSET_URL_FIELD_NUMBER: _builtins.int
        HEADER_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        HELP_ARTICLE_ID_FIELD_NUMBER: _builtins.int
        BUTTON_FIELD_NUMBER: _builtins.int
        DISMISSIBLE_CONTENT_FIELD_NUMBER: _builtins.int
        asset_url: _builtins.str
        header: _builtins.str
        body: _builtins.str
        help_article_id: _builtins.str
        dismissible_content: Global___PremiumMarketingComponentProperties.DismissibleContent.ValueType
        @_builtins.property
        def button(self) -> Global___PremiumMarketingComponentProperties.CTAButton: ...
        def __init__(
            self,
            *,
            asset_url: _builtins.str = ...,
            header: _builtins.str = ...,
            body: _builtins.str = ...,
            help_article_id: _builtins.str = ...,
            button: Global___PremiumMarketingComponentProperties.CTAButton | None = ...,
            dismissible_content: Global___PremiumMarketingComponentProperties.DismissibleContent.ValueType = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_button", b"_button", "button", b"button"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_button", b"_button", "asset_url", b"asset_url", "body", b"body", "button", b"button", "dismissible_content", b"dismissible_content", "header", b"header", "help_article_id", b"help_article_id"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__button: _TypeAlias = _typing.Literal["button"]  # noqa: Y015
        _WhichOneofArgType__button: _TypeAlias = _typing.Literal["_button", b"_button"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__button) -> _WhichOneofReturnType__button | None: ...

    @_typing.final
    class Gradient(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        COLORS_FIELD_NUMBER: _builtins.int
        ANGLE_FIELD_NUMBER: _builtins.int
        angle: _builtins.float
        @_builtins.property
        def colors(self) -> _containers.RepeatedScalarFieldContainer[_builtins.str]: ...
        def __init__(
            self,
            *,
            colors: _abc.Iterable[_builtins.str] | None = ...,
            angle: _builtins.float = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["angle", b"angle", "colors", b"colors"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class GiftIcon(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        BOX_ANIMATION_URL_FIELD_NUMBER: _builtins.int
        TRINKET_ANIMATION_URL_FIELD_NUMBER: _builtins.int
        TRINKET_GLOW_ANIMATION_URL_FIELD_NUMBER: _builtins.int
        GRADIENT_FIELD_NUMBER: _builtins.int
        box_animation_url: _builtins.str
        trinket_animation_url: _builtins.str
        trinket_glow_animation_url: _builtins.str
        @_builtins.property
        def gradient(self) -> Global___PremiumMarketingComponentProperties.Gradient: ...
        def __init__(
            self,
            *,
            box_animation_url: _builtins.str = ...,
            trinket_animation_url: _builtins.str = ...,
            trinket_glow_animation_url: _builtins.str = ...,
            gradient: Global___PremiumMarketingComponentProperties.Gradient | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_gradient", b"_gradient", "gradient", b"gradient"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_gradient", b"_gradient", "box_animation_url", b"box_animation_url", "gradient", b"gradient", "trinket_animation_url", b"trinket_animation_url", "trinket_glow_animation_url", b"trinket_glow_animation_url"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__gradient: _TypeAlias = _typing.Literal["gradient"]  # noqa: Y015
        _WhichOneofArgType__gradient: _TypeAlias = _typing.Literal["_gradient", b"_gradient"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__gradient) -> _WhichOneofReturnType__gradient | None: ...

    @_typing.final
    class ThemeAwareAsset(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        LIGHT_URL_FIELD_NUMBER: _builtins.int
        DARK_URL_FIELD_NUMBER: _builtins.int
        LIGHT_STATIC_URL_FIELD_NUMBER: _builtins.int
        DARK_STATIC_URL_FIELD_NUMBER: _builtins.int
        light_url: _builtins.str
        dark_url: _builtins.str
        light_static_url: _builtins.str
        dark_static_url: _builtins.str
        def __init__(
            self,
            *,
            light_url: _builtins.str = ...,
            dark_url: _builtins.str = ...,
            light_static_url: _builtins.str = ...,
            dark_static_url: _builtins.str = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["dark_static_url", b"dark_static_url", "dark_url", b"dark_url", "light_static_url", b"light_static_url", "light_url", b"light_url"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class GiftIconCoachmark(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        HEADER_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        ASSET_URL_FIELD_NUMBER: _builtins.int
        ASSET_FIELD_NUMBER: _builtins.int
        header: _builtins.str
        body: _builtins.str
        asset_url: _builtins.str
        @_builtins.property
        def asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        def __init__(
            self,
            *,
            header: _builtins.str = ...,
            body: _builtins.str = ...,
            asset_url: _builtins.str = ...,
            asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "asset", b"asset"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "asset", b"asset", "asset_url", b"asset_url", "body", b"body", "header", b"header"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__asset: _TypeAlias = _typing.Literal["asset"]  # noqa: Y015
        _WhichOneofArgType__asset: _TypeAlias = _typing.Literal["_asset", b"_asset"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__asset) -> _WhichOneofReturnType__asset | None: ...

    @_typing.final
    class GiftPlanSelectionCardBanner(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        HEADER_FIELD_NUMBER: _builtins.int
        DESKTOP_BODY_FIELD_NUMBER: _builtins.int
        MOBILE_BODY_FIELD_NUMBER: _builtins.int
        AVATAR_ASSET_FIELD_NUMBER: _builtins.int
        BANNER_ASSET_URL_FIELD_NUMBER: _builtins.int
        BACKGROUND_ASSET_URL_FIELD_NUMBER: _builtins.int
        CARD_ASSET_URL_FIELD_NUMBER: _builtins.int
        GRADIENT_FIELD_NUMBER: _builtins.int
        BANNER_ASSET_FIELD_NUMBER: _builtins.int
        BACKGROUND_ASSET_FIELD_NUMBER: _builtins.int
        CARD_ASSET_FIELD_NUMBER: _builtins.int
        MOBILE_BANNER_ASSET_FIELD_NUMBER: _builtins.int
        header: _builtins.str
        desktop_body: _builtins.str
        mobile_body: _builtins.str
        banner_asset_url: _builtins.str
        background_asset_url: _builtins.str
        card_asset_url: _builtins.str
        @_builtins.property
        def avatar_asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        @_builtins.property
        def gradient(self) -> Global___PremiumMarketingComponentProperties.Gradient: ...
        @_builtins.property
        def banner_asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        @_builtins.property
        def background_asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        @_builtins.property
        def card_asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        @_builtins.property
        def mobile_banner_asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        def __init__(
            self,
            *,
            header: _builtins.str = ...,
            desktop_body: _builtins.str = ...,
            mobile_body: _builtins.str = ...,
            avatar_asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
            banner_asset_url: _builtins.str = ...,
            background_asset_url: _builtins.str = ...,
            card_asset_url: _builtins.str = ...,
            gradient: Global___PremiumMarketingComponentProperties.Gradient | None = ...,
            banner_asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
            background_asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
            card_asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
            mobile_banner_asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_avatar_asset", b"_avatar_asset", "_background_asset", b"_background_asset", "_banner_asset", b"_banner_asset", "_card_asset", b"_card_asset", "_gradient", b"_gradient", "_mobile_banner_asset", b"_mobile_banner_asset", "avatar_asset", b"avatar_asset", "background_asset", b"background_asset", "banner_asset", b"banner_asset", "card_asset", b"card_asset", "gradient", b"gradient", "mobile_banner_asset", b"mobile_banner_asset"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_avatar_asset", b"_avatar_asset", "_background_asset", b"_background_asset", "_banner_asset", b"_banner_asset", "_card_asset", b"_card_asset", "_gradient", b"_gradient", "_mobile_banner_asset", b"_mobile_banner_asset", "avatar_asset", b"avatar_asset", "background_asset", b"background_asset", "background_asset_url", b"background_asset_url", "banner_asset", b"banner_asset", "banner_asset_url", b"banner_asset_url", "card_asset", b"card_asset", "card_asset_url", b"card_asset_url", "desktop_body", b"desktop_body", "gradient", b"gradient", "header", b"header", "mobile_banner_asset", b"mobile_banner_asset", "mobile_body", b"mobile_body"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__avatar_asset: _TypeAlias = _typing.Literal["avatar_asset"]  # noqa: Y015
        _WhichOneofArgType__avatar_asset: _TypeAlias = _typing.Literal["_avatar_asset", b"_avatar_asset"]  # noqa: Y015
        _WhichOneofReturnType__background_asset: _TypeAlias = _typing.Literal["background_asset"]  # noqa: Y015
        _WhichOneofArgType__background_asset: _TypeAlias = _typing.Literal["_background_asset", b"_background_asset"]  # noqa: Y015
        _WhichOneofReturnType__banner_asset: _TypeAlias = _typing.Literal["banner_asset"]  # noqa: Y015
        _WhichOneofArgType__banner_asset: _TypeAlias = _typing.Literal["_banner_asset", b"_banner_asset"]  # noqa: Y015
        _WhichOneofReturnType__card_asset: _TypeAlias = _typing.Literal["card_asset"]  # noqa: Y015
        _WhichOneofArgType__card_asset: _TypeAlias = _typing.Literal["_card_asset", b"_card_asset"]  # noqa: Y015
        _WhichOneofReturnType__gradient: _TypeAlias = _typing.Literal["gradient"]  # noqa: Y015
        _WhichOneofArgType__gradient: _TypeAlias = _typing.Literal["_gradient", b"_gradient"]  # noqa: Y015
        _WhichOneofReturnType__mobile_banner_asset: _TypeAlias = _typing.Literal["mobile_banner_asset"]  # noqa: Y015
        _WhichOneofArgType__mobile_banner_asset: _TypeAlias = _typing.Literal["_mobile_banner_asset", b"_mobile_banner_asset"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__avatar_asset) -> _WhichOneofReturnType__avatar_asset | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__background_asset) -> _WhichOneofReturnType__background_asset | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__banner_asset) -> _WhichOneofReturnType__banner_asset | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__card_asset) -> _WhichOneofReturnType__card_asset | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__gradient) -> _WhichOneofReturnType__gradient | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__mobile_banner_asset) -> _WhichOneofReturnType__mobile_banner_asset | None: ...

    @_typing.final
    class GiftCustomizationBanner(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ASSET_URL_FIELD_NUMBER: _builtins.int
        DESKTOP_BODY_FIELD_NUMBER: _builtins.int
        MOBILE_BODY_FIELD_NUMBER: _builtins.int
        GRADIENT_FIELD_NUMBER: _builtins.int
        BACKGROUND_ASSET_URL_FIELD_NUMBER: _builtins.int
        ASSET_FIELD_NUMBER: _builtins.int
        BACKGROUND_ASSET_FIELD_NUMBER: _builtins.int
        MOBILE_BACKGROUND_ASSET_FIELD_NUMBER: _builtins.int
        asset_url: _builtins.str
        desktop_body: _builtins.str
        mobile_body: _builtins.str
        background_asset_url: _builtins.str
        @_builtins.property
        def gradient(self) -> Global___PremiumMarketingComponentProperties.Gradient: ...
        @_builtins.property
        def asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        @_builtins.property
        def background_asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        @_builtins.property
        def mobile_background_asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        def __init__(
            self,
            *,
            asset_url: _builtins.str = ...,
            desktop_body: _builtins.str = ...,
            mobile_body: _builtins.str = ...,
            gradient: Global___PremiumMarketingComponentProperties.Gradient | None = ...,
            background_asset_url: _builtins.str = ...,
            asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
            background_asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
            mobile_background_asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "_background_asset", b"_background_asset", "_gradient", b"_gradient", "_mobile_background_asset", b"_mobile_background_asset", "asset", b"asset", "background_asset", b"background_asset", "gradient", b"gradient", "mobile_background_asset", b"mobile_background_asset"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "_background_asset", b"_background_asset", "_gradient", b"_gradient", "_mobile_background_asset", b"_mobile_background_asset", "asset", b"asset", "asset_url", b"asset_url", "background_asset", b"background_asset", "background_asset_url", b"background_asset_url", "desktop_body", b"desktop_body", "gradient", b"gradient", "mobile_background_asset", b"mobile_background_asset", "mobile_body", b"mobile_body"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__asset: _TypeAlias = _typing.Literal["asset"]  # noqa: Y015
        _WhichOneofArgType__asset: _TypeAlias = _typing.Literal["_asset", b"_asset"]  # noqa: Y015
        _WhichOneofReturnType__background_asset: _TypeAlias = _typing.Literal["background_asset"]  # noqa: Y015
        _WhichOneofArgType__background_asset: _TypeAlias = _typing.Literal["_background_asset", b"_background_asset"]  # noqa: Y015
        _WhichOneofReturnType__gradient: _TypeAlias = _typing.Literal["gradient"]  # noqa: Y015
        _WhichOneofArgType__gradient: _TypeAlias = _typing.Literal["_gradient", b"_gradient"]  # noqa: Y015
        _WhichOneofReturnType__mobile_background_asset: _TypeAlias = _typing.Literal["mobile_background_asset"]  # noqa: Y015
        _WhichOneofArgType__mobile_background_asset: _TypeAlias = _typing.Literal["_mobile_background_asset", b"_mobile_background_asset"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__asset) -> _WhichOneofReturnType__asset | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__background_asset) -> _WhichOneofReturnType__background_asset | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__gradient) -> _WhichOneofReturnType__gradient | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__mobile_background_asset) -> _WhichOneofReturnType__mobile_background_asset | None: ...

    @_typing.final
    class BillingSettingsNitroGiftBanner(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ASSET_URL_FIELD_NUMBER: _builtins.int
        HEADER_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        BACKGROUND_ASSET_URL_FIELD_NUMBER: _builtins.int
        GRADIENT_FIELD_NUMBER: _builtins.int
        TEXT_COLOR_FIELD_NUMBER: _builtins.int
        ADDITIONAL_TERMS_FIELD_NUMBER: _builtins.int
        ASSET_FIELD_NUMBER: _builtins.int
        BACKGROUND_ASSET_FIELD_NUMBER: _builtins.int
        asset_url: _builtins.str
        header: _builtins.str
        body: _builtins.str
        background_asset_url: _builtins.str
        text_color: _builtins.str
        additional_terms: _builtins.str
        @_builtins.property
        def gradient(self) -> Global___PremiumMarketingComponentProperties.Gradient: ...
        @_builtins.property
        def asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        @_builtins.property
        def background_asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        def __init__(
            self,
            *,
            asset_url: _builtins.str = ...,
            header: _builtins.str = ...,
            body: _builtins.str = ...,
            background_asset_url: _builtins.str = ...,
            gradient: Global___PremiumMarketingComponentProperties.Gradient | None = ...,
            text_color: _builtins.str = ...,
            additional_terms: _builtins.str = ...,
            asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
            background_asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "_background_asset", b"_background_asset", "_gradient", b"_gradient", "asset", b"asset", "background_asset", b"background_asset", "gradient", b"gradient"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "_background_asset", b"_background_asset", "_gradient", b"_gradient", "additional_terms", b"additional_terms", "asset", b"asset", "asset_url", b"asset_url", "background_asset", b"background_asset", "background_asset_url", b"background_asset_url", "body", b"body", "gradient", b"gradient", "header", b"header", "text_color", b"text_color"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__asset: _TypeAlias = _typing.Literal["asset"]  # noqa: Y015
        _WhichOneofArgType__asset: _TypeAlias = _typing.Literal["_asset", b"_asset"]  # noqa: Y015
        _WhichOneofReturnType__background_asset: _TypeAlias = _typing.Literal["background_asset"]  # noqa: Y015
        _WhichOneofArgType__background_asset: _TypeAlias = _typing.Literal["_background_asset", b"_background_asset"]  # noqa: Y015
        _WhichOneofReturnType__gradient: _TypeAlias = _typing.Literal["gradient"]  # noqa: Y015
        _WhichOneofArgType__gradient: _TypeAlias = _typing.Literal["_gradient", b"_gradient"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__asset) -> _WhichOneofReturnType__asset | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__background_asset) -> _WhichOneofReturnType__background_asset | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__gradient) -> _WhichOneofReturnType__gradient | None: ...

    @_typing.final
    class GiftReminderNagbar(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        BODY_FIELD_NUMBER: _builtins.int
        body: _builtins.str
        def __init__(
            self,
            *,
            body: _builtins.str = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["body", b"body"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class GiftReminderCoachmark(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        HEADER_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        ASSET_URL_FIELD_NUMBER: _builtins.int
        ASSET_FIELD_NUMBER: _builtins.int
        header: _builtins.str
        body: _builtins.str
        asset_url: _builtins.str
        @_builtins.property
        def asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        def __init__(
            self,
            *,
            header: _builtins.str = ...,
            body: _builtins.str = ...,
            asset_url: _builtins.str = ...,
            asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "asset", b"asset"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "asset", b"asset", "asset_url", b"asset_url", "body", b"body", "header", b"header"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__asset: _TypeAlias = _typing.Literal["asset"]  # noqa: Y015
        _WhichOneofArgType__asset: _TypeAlias = _typing.Literal["_asset", b"_asset"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__asset) -> _WhichOneofReturnType__asset | None: ...

    @_typing.final
    class PremiumTabTooltip(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        HEADER_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        ASSET_FIELD_NUMBER: _builtins.int
        header: _builtins.str
        body: _builtins.str
        @_builtins.property
        def asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        def __init__(
            self,
            *,
            header: _builtins.str = ...,
            body: _builtins.str = ...,
            asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "asset", b"asset"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "asset", b"asset", "body", b"body", "header", b"header"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__asset: _TypeAlias = _typing.Literal["asset"]  # noqa: Y015
        _WhichOneofArgType__asset: _TypeAlias = _typing.Literal["_asset", b"_asset"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__asset) -> _WhichOneofReturnType__asset | None: ...

    CONTENT_IDENTIFIER_FIELD_NUMBER: _builtins.int
    PLACEHOLDER_FIELD_NUMBER: _builtins.int
    ANNOUNCEMENT_MODAL_VARIANT_1_FIELD_NUMBER: _builtins.int
    PREMIUM_TAB_FIELD_NUMBER: _builtins.int
    MARKETING_PAGE_BANNER_FIELD_NUMBER: _builtins.int
    PAYMENT_MODAL_BANNER_FIELD_NUMBER: _builtins.int
    MOBILE_BOTTOM_SHEET_FIELD_NUMBER: _builtins.int
    GIFT_ICON_FIELD_NUMBER: _builtins.int
    GIFT_ICON_COACHMARK_FIELD_NUMBER: _builtins.int
    GIFT_PLAN_SELECTION_CARD_BANNER_FIELD_NUMBER: _builtins.int
    GIFT_CUSTOMIZATION_BANNER_FIELD_NUMBER: _builtins.int
    BILLING_SETTINGS_NITRO_GIFT_BANNER_FIELD_NUMBER: _builtins.int
    GIFT_REMINDER_NAGBAR_FIELD_NUMBER: _builtins.int
    GIFT_REMINDER_COACHMARK_FIELD_NUMBER: _builtins.int
    PREMIUM_TAB_TOOLTIP_FIELD_NUMBER: _builtins.int
    content_identifier: _builtins.str
    placeholder: _builtins.str
    @_builtins.property
    def announcement_modal_variant_1(self) -> Global___PremiumMarketingComponentProperties.AnnouncementModalVariant1Properties: ...
    @_builtins.property
    def premium_tab(self) -> Global___PremiumMarketingComponentProperties.PremiumTab: ...
    @_builtins.property
    def marketing_page_banner(self) -> Global___PremiumMarketingComponentProperties.MarketingPageBanner: ...
    @_builtins.property
    def payment_modal_banner(self) -> Global___PremiumMarketingComponentProperties.PaymentModalBanner: ...
    @_builtins.property
    def mobile_bottom_sheet(self) -> Global___PremiumMarketingComponentProperties.MobileBottomSheet: ...
    @_builtins.property
    def gift_icon(self) -> Global___PremiumMarketingComponentProperties.GiftIcon: ...
    @_builtins.property
    def gift_icon_coachmark(self) -> Global___PremiumMarketingComponentProperties.GiftIconCoachmark: ...
    @_builtins.property
    def gift_plan_selection_card_banner(self) -> Global___PremiumMarketingComponentProperties.GiftPlanSelectionCardBanner: ...
    @_builtins.property
    def gift_customization_banner(self) -> Global___PremiumMarketingComponentProperties.GiftCustomizationBanner: ...
    @_builtins.property
    def billing_settings_nitro_gift_banner(self) -> Global___PremiumMarketingComponentProperties.BillingSettingsNitroGiftBanner: ...
    @_builtins.property
    def gift_reminder_nagbar(self) -> Global___PremiumMarketingComponentProperties.GiftReminderNagbar: ...
    @_builtins.property
    def gift_reminder_coachmark(self) -> Global___PremiumMarketingComponentProperties.GiftReminderCoachmark: ...
    @_builtins.property
    def premium_tab_tooltip(self) -> Global___PremiumMarketingComponentProperties.PremiumTabTooltip: ...
    def __init__(
        self,
        *,
        content_identifier: _builtins.str = ...,
        placeholder: _builtins.str = ...,
        announcement_modal_variant_1: Global___PremiumMarketingComponentProperties.AnnouncementModalVariant1Properties | None = ...,
        premium_tab: Global___PremiumMarketingComponentProperties.PremiumTab | None = ...,
        marketing_page_banner: Global___PremiumMarketingComponentProperties.MarketingPageBanner | None = ...,
        payment_modal_banner: Global___PremiumMarketingComponentProperties.PaymentModalBanner | None = ...,
        mobile_bottom_sheet: Global___PremiumMarketingComponentProperties.MobileBottomSheet | None = ...,
        gift_icon: Global___PremiumMarketingComponentProperties.GiftIcon | None = ...,
        gift_icon_coachmark: Global___PremiumMarketingComponentProperties.GiftIconCoachmark | None = ...,
        gift_plan_selection_card_banner: Global___PremiumMarketingComponentProperties.GiftPlanSelectionCardBanner | None = ...,
        gift_customization_banner: Global___PremiumMarketingComponentProperties.GiftCustomizationBanner | None = ...,
        billing_settings_nitro_gift_banner: Global___PremiumMarketingComponentProperties.BillingSettingsNitroGiftBanner | None = ...,
        gift_reminder_nagbar: Global___PremiumMarketingComponentProperties.GiftReminderNagbar | None = ...,
        gift_reminder_coachmark: Global___PremiumMarketingComponentProperties.GiftReminderCoachmark | None = ...,
        premium_tab_tooltip: Global___PremiumMarketingComponentProperties.PremiumTabTooltip | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["announcement_modal_variant_1", b"announcement_modal_variant_1", "billing_settings_nitro_gift_banner", b"billing_settings_nitro_gift_banner", "gift_customization_banner", b"gift_customization_banner", "gift_icon", b"gift_icon", "gift_icon_coachmark", b"gift_icon_coachmark", "gift_plan_selection_card_banner", b"gift_plan_selection_card_banner", "gift_reminder_coachmark", b"gift_reminder_coachmark", "gift_reminder_nagbar", b"gift_reminder_nagbar", "marketing_page_banner", b"marketing_page_banner", "mobile_bottom_sheet", b"mobile_bottom_sheet", "payment_modal_banner", b"payment_modal_banner", "placeholder", b"placeholder", "premium_tab", b"premium_tab", "premium_tab_tooltip", b"premium_tab_tooltip", "properties", b"properties"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["announcement_modal_variant_1", b"announcement_modal_variant_1", "billing_settings_nitro_gift_banner", b"billing_settings_nitro_gift_banner", "content_identifier", b"content_identifier", "gift_customization_banner", b"gift_customization_banner", "gift_icon", b"gift_icon", "gift_icon_coachmark", b"gift_icon_coachmark", "gift_plan_selection_card_banner", b"gift_plan_selection_card_banner", "gift_reminder_coachmark", b"gift_reminder_coachmark", "gift_reminder_nagbar", b"gift_reminder_nagbar", "marketing_page_banner", b"marketing_page_banner", "mobile_bottom_sheet", b"mobile_bottom_sheet", "payment_modal_banner", b"payment_modal_banner", "placeholder", b"placeholder", "premium_tab", b"premium_tab", "premium_tab_tooltip", b"premium_tab_tooltip", "properties", b"properties"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType_properties: _TypeAlias = _typing.Literal["placeholder", "announcement_modal_variant_1", "premium_tab", "marketing_page_banner", "payment_modal_banner", "mobile_bottom_sheet", "gift_icon", "gift_icon_coachmark", "gift_plan_selection_card_banner", "gift_customization_banner", "billing_settings_nitro_gift_banner", "gift_reminder_nagbar", "gift_reminder_coachmark", "premium_tab_tooltip"]  # noqa: Y015
    _WhichOneofArgType_properties: _TypeAlias = _typing.Literal["properties", b"properties"]  # noqa: Y015
    def WhichOneof(self, oneof_group: _WhichOneofArgType_properties) -> _WhichOneofReturnType_properties | None: ...

Global___PremiumMarketingComponentProperties: _TypeAlias = PremiumMarketingComponentProperties  # noqa: Y015
